# -*- coding: iso-8859-1 -*-
"""Raw (C-style) API for OpenGL.GLU

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw.GLU.constants import *

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid

FUNCTION_TYPE = platform.PLATFORM.functionTypeFor( platform.PLATFORM.GLU )
from OpenGL.raw.GL._types import (
    GLint,
    GLenum,
    GLsizei,
    GLboolean,
    GLubyte,
    GLdouble,
    GLfloat,
)


class GLUnurbs(Structure):
    pass
GLUnurbs._fields_ = [
    # /usr/include/GL/glu.h 257
]
GLUnurbsObj = GLUnurbs
class GLUquadric(Structure):
    pass
GLUquadric._fields_ = [
    # /usr/include/GL/glu.h 258
]
GLUquadricObj = GLUquadric
class GLUtesselator(Structure):
    pass
GLUtesselator._fields_ = [
    # /usr/include/GL/glu.h 259
]
GLUtesselatorObj = GLUtesselator
GLUtriangulatorObj = GLUtesselator


# /usr/include/GL/glu.h 276
gluBeginCurve = platform.createBaseFunction( 
    'gluBeginCurve', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs)],
    doc='gluBeginCurve( POINTER(GLUnurbs)(nurb) ) -> None', 
    argNames=('nurb',),
)


# /usr/include/GL/glu.h 277
gluBeginPolygon = platform.createBaseFunction( 
    'gluBeginPolygon', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator)],
    doc='gluBeginPolygon( POINTER(GLUtesselator)(tess) ) -> None', 
    argNames=('tess',),
)


# /usr/include/GL/glu.h 278
gluBeginSurface = platform.createBaseFunction( 
    'gluBeginSurface', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs)],
    doc='gluBeginSurface( POINTER(GLUnurbs)(nurb) ) -> None', 
    argNames=('nurb',),
)


# /usr/include/GL/glu.h 279
gluBeginTrim = platform.createBaseFunction( 
    'gluBeginTrim', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs)],
    doc='gluBeginTrim( POINTER(GLUnurbs)(nurb) ) -> None', 
    argNames=('nurb',),
)


# /usr/include/GL/glu.h 280
gluBuild1DMipmapLevels = platform.createBaseFunction( 
    'gluBuild1DMipmapLevels', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLenum,GLint,GLsizei,GLenum,GLenum,GLint,GLint,GLint,c_void_p],
    doc='gluBuild1DMipmapLevels( GLenum(target), GLint(internalFormat), GLsizei(width), GLenum(format), GLenum(type), GLint(level), GLint(base), GLint(max), c_void_p(data) ) -> GLint', 
    argNames=('target', 'internalFormat', 'width', 'format', 'type', 'level', 'base', 'max', 'data'),
)


# /usr/include/GL/glu.h 281
gluBuild1DMipmaps = platform.createBaseFunction( 
    'gluBuild1DMipmaps', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLenum,GLint,GLsizei,GLenum,GLenum,c_void_p],
    doc='gluBuild1DMipmaps( GLenum(target), GLint(internalFormat), GLsizei(width), GLenum(format), GLenum(type), c_void_p(data) ) -> GLint', 
    argNames=('target', 'internalFormat', 'width', 'format', 'type', 'data'),
)


# /usr/include/GL/glu.h 282
gluBuild2DMipmapLevels = platform.createBaseFunction( 
    'gluBuild2DMipmapLevels', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLenum,GLint,GLsizei,GLsizei,GLenum,GLenum,GLint,GLint,GLint,c_void_p],
    doc='gluBuild2DMipmapLevels( GLenum(target), GLint(internalFormat), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), GLint(level), GLint(base), GLint(max), c_void_p(data) ) -> GLint', 
    argNames=('target', 'internalFormat', 'width', 'height', 'format', 'type', 'level', 'base', 'max', 'data'),
)


# /usr/include/GL/glu.h 283
gluBuild2DMipmaps = platform.createBaseFunction( 
    'gluBuild2DMipmaps', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLenum,GLint,GLsizei,GLsizei,GLenum,GLenum,c_void_p],
    doc='gluBuild2DMipmaps( GLenum(target), GLint(internalFormat), GLsizei(width), GLsizei(height), GLenum(format), GLenum(type), c_void_p(data) ) -> GLint', 
    argNames=('target', 'internalFormat', 'width', 'height', 'format', 'type', 'data'),
)


# /usr/include/GL/glu.h 284
gluBuild3DMipmapLevels = platform.createBaseFunction( 
    'gluBuild3DMipmapLevels', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLenum,GLint,GLsizei,GLsizei,GLsizei,GLenum,GLenum,GLint,GLint,GLint,c_void_p],
    doc='gluBuild3DMipmapLevels( GLenum(target), GLint(internalFormat), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), GLint(level), GLint(base), GLint(max), c_void_p(data) ) -> GLint', 
    argNames=('target', 'internalFormat', 'width', 'height', 'depth', 'format', 'type', 'level', 'base', 'max', 'data'),
)


# /usr/include/GL/glu.h 285
gluBuild3DMipmaps = platform.createBaseFunction( 
    'gluBuild3DMipmaps', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLenum,GLint,GLsizei,GLsizei,GLsizei,GLenum,GLenum,c_void_p],
    doc='gluBuild3DMipmaps( GLenum(target), GLint(internalFormat), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLenum(type), c_void_p(data) ) -> GLint', 
    argNames=('target', 'internalFormat', 'width', 'height', 'depth', 'format', 'type', 'data'),
)


# /usr/include/GL/glu.h 286
gluCheckExtension = platform.createBaseFunction( 
    'gluCheckExtension', dll=platform.PLATFORM.GLU, resultType=GLboolean, 
    argTypes=[arrays.GLubyteArray,arrays.GLubyteArray],
    doc='gluCheckExtension( arrays.GLubyteArray(extName), arrays.GLubyteArray(extString) ) -> GLboolean', 
    argNames=('extName', 'extString'),
)


# /usr/include/GL/glu.h 287
gluCylinder = platform.createBaseFunction( 
    'gluCylinder', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLdouble,GLdouble,GLdouble,GLint,GLint],
    doc='gluCylinder( POINTER(GLUquadric)(quad), GLdouble(base), GLdouble(top), GLdouble(height), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('quad', 'base', 'top', 'height', 'slices', 'stacks'),
)


# /usr/include/GL/glu.h 288
gluDeleteNurbsRenderer = platform.createBaseFunction( 
    'gluDeleteNurbsRenderer', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs)],
    doc='gluDeleteNurbsRenderer( POINTER(GLUnurbs)(nurb) ) -> None', 
    argNames=('nurb',),
)


# /usr/include/GL/glu.h 289
gluDeleteQuadric = platform.createBaseFunction( 
    'gluDeleteQuadric', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric)],
    doc='gluDeleteQuadric( POINTER(GLUquadric)(quad) ) -> None', 
    argNames=('quad',),
)


# /usr/include/GL/glu.h 290
gluDeleteTess = platform.createBaseFunction( 
    'gluDeleteTess', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator)],
    doc='gluDeleteTess( POINTER(GLUtesselator)(tess) ) -> None', 
    argNames=('tess',),
)


# /usr/include/GL/glu.h 291
gluDisk = platform.createBaseFunction( 
    'gluDisk', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLdouble,GLdouble,GLint,GLint],
    doc='gluDisk( POINTER(GLUquadric)(quad), GLdouble(inner), GLdouble(outer), GLint(slices), GLint(loops) ) -> None', 
    argNames=('quad', 'inner', 'outer', 'slices', 'loops'),
)


# /usr/include/GL/glu.h 292
gluEndCurve = platform.createBaseFunction( 
    'gluEndCurve', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs)],
    doc='gluEndCurve( POINTER(GLUnurbs)(nurb) ) -> None', 
    argNames=('nurb',),
)


# /usr/include/GL/glu.h 293
gluEndPolygon = platform.createBaseFunction( 
    'gluEndPolygon', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator)],
    doc='gluEndPolygon( POINTER(GLUtesselator)(tess) ) -> None', 
    argNames=('tess',),
)


# /usr/include/GL/glu.h 294
gluEndSurface = platform.createBaseFunction( 
    'gluEndSurface', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs)],
    doc='gluEndSurface( POINTER(GLUnurbs)(nurb) ) -> None', 
    argNames=('nurb',),
)


# /usr/include/GL/glu.h 295
gluEndTrim = platform.createBaseFunction( 
    'gluEndTrim', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs)],
    doc='gluEndTrim( POINTER(GLUnurbs)(nurb) ) -> None', 
    argNames=('nurb',),
)


# /usr/include/GL/glu.h 296
gluErrorString = platform.createBaseFunction( 
    'gluErrorString', dll=platform.PLATFORM.GLU, resultType=POINTER(GLubyte), 
    argTypes=[GLenum],
    doc='gluErrorString( GLenum(error) ) -> POINTER(GLubyte)', 
    argNames=('error',),
)


# /usr/include/GL/glu.h 297
gluGetNurbsProperty = platform.createBaseFunction( 
    'gluGetNurbsProperty', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),GLenum,arrays.GLfloatArray],
    doc='gluGetNurbsProperty( POINTER(GLUnurbs)(nurb), GLenum(property), arrays.GLfloatArray(data) ) -> None', 
    argNames=('nurb', 'property', 'data'),
)


# /usr/include/GL/glu.h 298
gluGetString = platform.createBaseFunction( 
    'gluGetString', dll=platform.PLATFORM.GLU, resultType=POINTER(GLubyte), 
    argTypes=[GLenum],
    doc='gluGetString( GLenum(name) ) -> POINTER(GLubyte)', 
    argNames=('name',),
)


# /usr/include/GL/glu.h 299
gluGetTessProperty = platform.createBaseFunction( 
    'gluGetTessProperty', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator),GLenum,arrays.GLdoubleArray],
    doc='gluGetTessProperty( POINTER(GLUtesselator)(tess), GLenum(which), arrays.GLdoubleArray(data) ) -> None', 
    argNames=('tess', 'which', 'data'),
)


# /usr/include/GL/glu.h 300
gluLoadSamplingMatrices = platform.createBaseFunction( 
    'gluLoadSamplingMatrices', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),arrays.GLfloatArray,arrays.GLfloatArray,arrays.GLintArray],
    doc='gluLoadSamplingMatrices( POINTER(GLUnurbs)(nurb), arrays.GLfloatArray(model), arrays.GLfloatArray(perspective), arrays.GLintArray(view) ) -> None', 
    argNames=('nurb', 'model', 'perspective', 'view'),
)


# /usr/include/GL/glu.h 301
gluLookAt = platform.createBaseFunction( 
    'gluLookAt', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble],
    doc='gluLookAt( GLdouble(eyeX), GLdouble(eyeY), GLdouble(eyeZ), GLdouble(centerX), GLdouble(centerY), GLdouble(centerZ), GLdouble(upX), GLdouble(upY), GLdouble(upZ) ) -> None', 
    argNames=('eyeX', 'eyeY', 'eyeZ', 'centerX', 'centerY', 'centerZ', 'upX', 'upY', 'upZ'),
)


# /usr/include/GL/glu.h 302
gluNewNurbsRenderer = platform.createBaseFunction( 
    'gluNewNurbsRenderer', dll=platform.PLATFORM.GLU, resultType=POINTER(GLUnurbs), 
    argTypes=[],
    doc='gluNewNurbsRenderer(  ) -> POINTER(GLUnurbs)', 
    argNames=(),
)


# /usr/include/GL/glu.h 303
gluNewQuadric = platform.createBaseFunction( 
    'gluNewQuadric', dll=platform.PLATFORM.GLU, resultType=POINTER(GLUquadric), 
    argTypes=[],
    doc='gluNewQuadric(  ) -> POINTER(GLUquadric)', 
    argNames=(),
)


# /usr/include/GL/glu.h 304
gluNewTess = platform.createBaseFunction( 
    'gluNewTess', dll=platform.PLATFORM.GLU, resultType=POINTER(GLUtesselator), 
    argTypes=[],
    doc='gluNewTess(  ) -> POINTER(GLUtesselator)', 
    argNames=(),
)


# /usr/include/GL/glu.h 305
gluNextContour = platform.createBaseFunction( 
    'gluNextContour', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator),GLenum],
    doc='gluNextContour( POINTER(GLUtesselator)(tess), GLenum(type) ) -> None', 
    argNames=('tess', 'type'),
)


_GLUfuncptr = FUNCTION_TYPE(None)
# /usr/include/GL/glu.h 306
gluNurbsCallback = platform.createBaseFunction( 
    'gluNurbsCallback', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),GLenum,_GLUfuncptr],
    doc='gluNurbsCallback( POINTER(GLUnurbs)(nurb), GLenum(which), _GLUfuncptr(CallBackFunc) ) -> None', 
    argNames=('nurb', 'which', 'CallBackFunc'),
)

GLvoid = None
# /usr/include/GL/glu.h 307
gluNurbsCallbackData = platform.createBaseFunction( 
    'gluNurbsCallbackData', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),POINTER(GLvoid)],
    doc='gluNurbsCallbackData( POINTER(GLUnurbs)(nurb), POINTER(GLvoid)(userData) ) -> None', 
    argNames=('nurb', 'userData'),
)


# /usr/include/GL/glu.h 308
gluNurbsCallbackDataEXT = platform.createBaseFunction( 
    'gluNurbsCallbackDataEXT', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),POINTER(GLvoid)],
    doc='gluNurbsCallbackDataEXT( POINTER(GLUnurbs)(nurb), POINTER(GLvoid)(userData) ) -> None', 
    argNames=('nurb', 'userData'),
)


# /usr/include/GL/glu.h 309
gluNurbsCurve = platform.createBaseFunction( 
    'gluNurbsCurve', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),GLint,arrays.GLfloatArray,GLint,arrays.GLfloatArray,GLint,GLenum],
    doc='gluNurbsCurve( POINTER(GLUnurbs)(nurb), GLint(knotCount), arrays.GLfloatArray(knots), GLint(stride), arrays.GLfloatArray(control), GLint(order), GLenum(type) ) -> None', 
    argNames=('nurb', 'knotCount', 'knots', 'stride', 'control', 'order', 'type'),
)


# /usr/include/GL/glu.h 310
gluNurbsProperty = platform.createBaseFunction( 
    'gluNurbsProperty', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),GLenum,GLfloat],
    doc='gluNurbsProperty( POINTER(GLUnurbs)(nurb), GLenum(property), GLfloat(value) ) -> None', 
    argNames=('nurb', 'property', 'value'),
)


# /usr/include/GL/glu.h 311
gluNurbsSurface = platform.createBaseFunction( 
    'gluNurbsSurface', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),GLint,arrays.GLfloatArray,GLint,arrays.GLfloatArray,GLint,GLint,arrays.GLfloatArray,GLint,GLint,GLenum],
    doc='gluNurbsSurface( POINTER(GLUnurbs)(nurb), GLint(sKnotCount), arrays.GLfloatArray(sKnots), GLint(tKnotCount), arrays.GLfloatArray(tKnots), GLint(sStride), GLint(tStride), arrays.GLfloatArray(control), GLint(sOrder), GLint(tOrder), GLenum(type) ) -> None', 
    argNames=('nurb', 'sKnotCount', 'sKnots', 'tKnotCount', 'tKnots', 'sStride', 'tStride', 'control', 'sOrder', 'tOrder', 'type'),
)


# /usr/include/GL/glu.h 312
gluOrtho2D = platform.createBaseFunction( 
    'gluOrtho2D', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLdouble,GLdouble],
    doc='gluOrtho2D( GLdouble(left), GLdouble(right), GLdouble(bottom), GLdouble(top) ) -> None', 
    argNames=('left', 'right', 'bottom', 'top'),
)


# /usr/include/GL/glu.h 313
gluPartialDisk = platform.createBaseFunction( 
    'gluPartialDisk', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLdouble,GLdouble,GLint,GLint,GLdouble,GLdouble],
    doc='gluPartialDisk( POINTER(GLUquadric)(quad), GLdouble(inner), GLdouble(outer), GLint(slices), GLint(loops), GLdouble(start), GLdouble(sweep) ) -> None', 
    argNames=('quad', 'inner', 'outer', 'slices', 'loops', 'start', 'sweep'),
)


# /usr/include/GL/glu.h 314
gluPerspective = platform.createBaseFunction( 
    'gluPerspective', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLdouble,GLdouble],
    doc='gluPerspective( GLdouble(fovy), GLdouble(aspect), GLdouble(zNear), GLdouble(zFar) ) -> None', 
    argNames=('fovy', 'aspect', 'zNear', 'zFar'),
)


# /usr/include/GL/glu.h 315
gluPickMatrix = platform.createBaseFunction( 
    'gluPickMatrix', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[GLdouble,GLdouble,GLdouble,GLdouble,arrays.GLintArray],
    doc='gluPickMatrix( GLdouble(x), GLdouble(y), GLdouble(delX), GLdouble(delY), arrays.GLintArray(viewport) ) -> None', 
    argNames=('x', 'y', 'delX', 'delY', 'viewport'),
)


# /usr/include/GL/glu.h 316
gluProject = platform.createBaseFunction( 
    'gluProject', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLdouble,GLdouble,GLdouble,arrays.GLdoubleArray,arrays.GLdoubleArray,arrays.GLintArray,arrays.GLdoubleArray,arrays.GLdoubleArray,arrays.GLdoubleArray],
    doc='gluProject( GLdouble(objX), GLdouble(objY), GLdouble(objZ), arrays.GLdoubleArray(model), arrays.GLdoubleArray(proj), arrays.GLintArray(view), arrays.GLdoubleArray(winX), arrays.GLdoubleArray(winY), arrays.GLdoubleArray(winZ) ) -> GLint', 
    argNames=('objX', 'objY', 'objZ', 'model', 'proj', 'view', 'winX', 'winY', 'winZ'),
)


# /usr/include/GL/glu.h 317
gluPwlCurve = platform.createBaseFunction( 
    'gluPwlCurve', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUnurbs),GLint,arrays.GLfloatArray,GLint,GLenum],
    doc='gluPwlCurve( POINTER(GLUnurbs)(nurb), GLint(count), arrays.GLfloatArray(data), GLint(stride), GLenum(type) ) -> None', 
    argNames=('nurb', 'count', 'data', 'stride', 'type'),
)


# /usr/include/GL/glu.h 318
gluQuadricCallback = platform.createBaseFunction( 
    'gluQuadricCallback', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLenum,_GLUfuncptr],
    doc='gluQuadricCallback( POINTER(GLUquadric)(quad), GLenum(which), _GLUfuncptr(CallBackFunc) ) -> None', 
    argNames=('quad', 'which', 'CallBackFunc'),
)


# /usr/include/GL/glu.h 319
gluQuadricDrawStyle = platform.createBaseFunction( 
    'gluQuadricDrawStyle', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLenum],
    doc='gluQuadricDrawStyle( POINTER(GLUquadric)(quad), GLenum(draw) ) -> None', 
    argNames=('quad', 'draw'),
)


# /usr/include/GL/glu.h 320
gluQuadricNormals = platform.createBaseFunction( 
    'gluQuadricNormals', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLenum],
    doc='gluQuadricNormals( POINTER(GLUquadric)(quad), GLenum(normal) ) -> None', 
    argNames=('quad', 'normal'),
)


# /usr/include/GL/glu.h 321
gluQuadricOrientation = platform.createBaseFunction( 
    'gluQuadricOrientation', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLenum],
    doc='gluQuadricOrientation( POINTER(GLUquadric)(quad), GLenum(orientation) ) -> None', 
    argNames=('quad', 'orientation'),
)


# /usr/include/GL/glu.h 322
gluQuadricTexture = platform.createBaseFunction( 
    'gluQuadricTexture', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLboolean],
    doc='gluQuadricTexture( POINTER(GLUquadric)(quad), GLboolean(texture) ) -> None', 
    argNames=('quad', 'texture'),
)


# /usr/include/GL/glu.h 323
gluScaleImage = platform.createBaseFunction( 
    'gluScaleImage', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLenum,GLsizei,GLsizei,GLenum,c_void_p,GLsizei,GLsizei,GLenum,POINTER(GLvoid)],
    doc='gluScaleImage( GLenum(format), GLsizei(wIn), GLsizei(hIn), GLenum(typeIn), c_void_p(dataIn), GLsizei(wOut), GLsizei(hOut), GLenum(typeOut), POINTER(GLvoid)(dataOut) ) -> GLint', 
    argNames=('format', 'wIn', 'hIn', 'typeIn', 'dataIn', 'wOut', 'hOut', 'typeOut', 'dataOut'),
)


# /usr/include/GL/glu.h 324
gluSphere = platform.createBaseFunction( 
    'gluSphere', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUquadric),GLdouble,GLint,GLint],
    doc='gluSphere( POINTER(GLUquadric)(quad), GLdouble(radius), GLint(slices), GLint(stacks) ) -> None', 
    argNames=('quad', 'radius', 'slices', 'stacks'),
)


# /usr/include/GL/glu.h 325
gluTessBeginContour = platform.createBaseFunction( 
    'gluTessBeginContour', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator)],
    doc='gluTessBeginContour( POINTER(GLUtesselator)(tess) ) -> None', 
    argNames=('tess',),
)


# /usr/include/GL/glu.h 326
gluTessBeginPolygon = platform.createBaseFunction( 
    'gluTessBeginPolygon', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator),POINTER(GLvoid)],
    doc='gluTessBeginPolygon( POINTER(GLUtesselator)(tess), POINTER(GLvoid)(data) ) -> None', 
    argNames=('tess', 'data'),
)


# /usr/include/GL/glu.h 327
gluTessCallback = platform.createBaseFunction( 
    'gluTessCallback', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator),GLenum,_GLUfuncptr],
    doc='gluTessCallback( POINTER(GLUtesselator)(tess), GLenum(which), _GLUfuncptr(CallBackFunc) ) -> None', 
    argNames=('tess', 'which', 'CallBackFunc'),
)


# /usr/include/GL/glu.h 328
gluTessEndContour = platform.createBaseFunction( 
    'gluTessEndContour', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator)],
    doc='gluTessEndContour( POINTER(GLUtesselator)(tess) ) -> None', 
    argNames=('tess',),
)


# /usr/include/GL/glu.h 329
gluTessEndPolygon = platform.createBaseFunction( 
    'gluTessEndPolygon', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator)],
    doc='gluTessEndPolygon( POINTER(GLUtesselator)(tess) ) -> None', 
    argNames=('tess',),
)


# /usr/include/GL/glu.h 330
gluTessNormal = platform.createBaseFunction( 
    'gluTessNormal', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator),GLdouble,GLdouble,GLdouble],
    doc='gluTessNormal( POINTER(GLUtesselator)(tess), GLdouble(valueX), GLdouble(valueY), GLdouble(valueZ) ) -> None', 
    argNames=('tess', 'valueX', 'valueY', 'valueZ'),
)


# /usr/include/GL/glu.h 331
gluTessProperty = platform.createBaseFunction( 
    'gluTessProperty', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator),GLenum,GLdouble],
    doc='gluTessProperty( POINTER(GLUtesselator)(tess), GLenum(which), GLdouble(data) ) -> None', 
    argNames=('tess', 'which', 'data'),
)


# /usr/include/GL/glu.h 332
gluTessVertex = platform.createBaseFunction( 
    'gluTessVertex', dll=platform.PLATFORM.GLU, resultType=None, 
    argTypes=[POINTER(GLUtesselator),arrays.GLdoubleArray,POINTER(GLvoid)],
    doc='gluTessVertex( POINTER(GLUtesselator)(tess), arrays.GLdoubleArray(location), POINTER(GLvoid)(data) ) -> None', 
    argNames=('tess', 'location', 'data'),
)


# /usr/include/GL/glu.h 333
gluUnProject = platform.createBaseFunction( 
    'gluUnProject', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLdouble,GLdouble,GLdouble,arrays.GLdoubleArray,arrays.GLdoubleArray,arrays.GLintArray,arrays.GLdoubleArray,arrays.GLdoubleArray,arrays.GLdoubleArray],
    doc='gluUnProject( GLdouble(winX), GLdouble(winY), GLdouble(winZ), arrays.GLdoubleArray(model), arrays.GLdoubleArray(proj), arrays.GLintArray(view), arrays.GLdoubleArray(objX), arrays.GLdoubleArray(objY), arrays.GLdoubleArray(objZ) ) -> GLint', 
    argNames=('winX', 'winY', 'winZ', 'model', 'proj', 'view', 'objX', 'objY', 'objZ'),
)


# /usr/include/GL/glu.h 334
gluUnProject4 = platform.createBaseFunction( 
    'gluUnProject4', dll=platform.PLATFORM.GLU, resultType=GLint, 
    argTypes=[GLdouble,GLdouble,GLdouble,GLdouble,arrays.GLdoubleArray,arrays.GLdoubleArray,arrays.GLintArray,GLdouble,GLdouble,arrays.GLdoubleArray,arrays.GLdoubleArray,arrays.GLdoubleArray,arrays.GLdoubleArray],
    doc='gluUnProject4( GLdouble(winX), GLdouble(winY), GLdouble(winZ), GLdouble(clipW), arrays.GLdoubleArray(model), arrays.GLdoubleArray(proj), arrays.GLintArray(view), GLdouble(nearVal), GLdouble(farVal), arrays.GLdoubleArray(objX), arrays.GLdoubleArray(objY), arrays.GLdoubleArray(objZ), arrays.GLdoubleArray(objW) ) -> GLint', 
    argNames=('winX', 'winY', 'winZ', 'clipW', 'model', 'proj', 'view', 'nearVal', 'farVal', 'objX', 'objY', 'objZ', 'objW'),
)

__all__ = [
    'GLU_AUTO_LOAD_MATRIX',
    'GLU_BEGIN',
    'GLU_CCW',
    'GLU_CULLING',
    'GLU_CW',
    'GLU_DISPLAY_MODE',
    'GLU_DOMAIN_DISTANCE',
    'GLU_EDGE_FLAG',
    'GLU_END',
    'GLU_ERROR',
    'GLU_EXTENSIONS',
    'GLU_EXTERIOR',
    'GLU_FALSE',
    'GLU_FILL',
    'GLU_FLAT',
    'GLU_INCOMPATIBLE_GL_VERSION',
    'GLU_INSIDE',
    'GLU_INTERIOR',
    'GLU_INVALID_ENUM',
    'GLU_INVALID_OPERATION',
    'GLU_INVALID_VALUE',
    'GLU_LINE',
    'GLU_MAP1_TRIM_2',
    'GLU_MAP1_TRIM_3',
    'GLU_NONE',
    'GLU_NURBS_BEGIN',
    'GLU_NURBS_BEGIN_DATA',
    'GLU_NURBS_BEGIN_DATA_EXT',
    'GLU_NURBS_BEGIN_EXT',
    'GLU_NURBS_COLOR',
    'GLU_NURBS_COLOR_DATA',
    'GLU_NURBS_COLOR_DATA_EXT',
    'GLU_NURBS_COLOR_EXT',
    'GLU_NURBS_END',
    'GLU_NURBS_END_DATA',
    'GLU_NURBS_END_DATA_EXT',
    'GLU_NURBS_END_EXT',
    'GLU_NURBS_ERROR',
    'GLU_NURBS_ERROR1',
    'GLU_NURBS_ERROR10',
    'GLU_NURBS_ERROR11',
    'GLU_NURBS_ERROR12',
    'GLU_NURBS_ERROR13',
    'GLU_NURBS_ERROR14',
    'GLU_NURBS_ERROR15',
    'GLU_NURBS_ERROR16',
    'GLU_NURBS_ERROR17',
    'GLU_NURBS_ERROR18',
    'GLU_NURBS_ERROR19',
    'GLU_NURBS_ERROR2',
    'GLU_NURBS_ERROR20',
    'GLU_NURBS_ERROR21',
    'GLU_NURBS_ERROR22',
    'GLU_NURBS_ERROR23',
    'GLU_NURBS_ERROR24',
    'GLU_NURBS_ERROR25',
    'GLU_NURBS_ERROR26',
    'GLU_NURBS_ERROR27',
    'GLU_NURBS_ERROR28',
    'GLU_NURBS_ERROR29',
    'GLU_NURBS_ERROR3',
    'GLU_NURBS_ERROR30',
    'GLU_NURBS_ERROR31',
    'GLU_NURBS_ERROR32',
    'GLU_NURBS_ERROR33',
    'GLU_NURBS_ERROR34',
    'GLU_NURBS_ERROR35',
    'GLU_NURBS_ERROR36',
    'GLU_NURBS_ERROR37',
    'GLU_NURBS_ERROR4',
    'GLU_NURBS_ERROR5',
    'GLU_NURBS_ERROR6',
    'GLU_NURBS_ERROR7',
    'GLU_NURBS_ERROR8',
    'GLU_NURBS_ERROR9',
    'GLU_NURBS_MODE',
    'GLU_NURBS_MODE_EXT',
    'GLU_NURBS_NORMAL',
    'GLU_NURBS_NORMAL_DATA',
    'GLU_NURBS_NORMAL_DATA_EXT',
    'GLU_NURBS_NORMAL_EXT',
    'GLU_NURBS_RENDERER',
    'GLU_NURBS_RENDERER_EXT',
    'GLU_NURBS_TESSELLATOR',
    'GLU_NURBS_TESSELLATOR_EXT',
    'GLU_NURBS_TEXTURE_COORD',
    'GLU_NURBS_TEXTURE_COORD_DATA',
    'GLU_NURBS_TEX_COORD_DATA_EXT',
    'GLU_NURBS_TEX_COORD_EXT',
    'GLU_NURBS_VERTEX',
    'GLU_NURBS_VERTEX_DATA',
    'GLU_NURBS_VERTEX_DATA_EXT',
    'GLU_NURBS_VERTEX_EXT',
    'GLU_OBJECT_PARAMETRIC_ERROR',
    'GLU_OBJECT_PARAMETRIC_ERROR_EXT',
    'GLU_OBJECT_PATH_LENGTH',
    'GLU_OBJECT_PATH_LENGTH_EXT',
    'GLU_OUTLINE_PATCH',
    'GLU_OUTLINE_POLYGON',
    'GLU_OUTSIDE',
    'GLU_OUT_OF_MEMORY',
    'GLU_PARAMETRIC_ERROR',
    'GLU_PARAMETRIC_TOLERANCE',
    'GLU_PATH_LENGTH',
    'GLU_POINT',
    'GLU_SAMPLING_METHOD',
    'GLU_SAMPLING_TOLERANCE',
    'GLU_SILHOUETTE',
    'GLU_SMOOTH',
    'GLU_TESS_BEGIN',
    'GLU_TESS_BEGIN_DATA',
    'GLU_TESS_BOUNDARY_ONLY',
    'GLU_TESS_COMBINE',
    'GLU_TESS_COMBINE_DATA',
    'GLU_TESS_COORD_TOO_LARGE',
    'GLU_TESS_EDGE_FLAG',
    'GLU_TESS_EDGE_FLAG_DATA',
    'GLU_TESS_END',
    'GLU_TESS_END_DATA',
    'GLU_TESS_ERROR',
    'GLU_TESS_ERROR1',
    'GLU_TESS_ERROR2',
    'GLU_TESS_ERROR3',
    'GLU_TESS_ERROR4',
    'GLU_TESS_ERROR5',
    'GLU_TESS_ERROR6',
    'GLU_TESS_ERROR7',
    'GLU_TESS_ERROR8',
    'GLU_TESS_ERROR_DATA',
    'GLU_TESS_MAX_COORD',
    'GLU_TESS_MISSING_BEGIN_CONTOUR',
    'GLU_TESS_MISSING_BEGIN_POLYGON',
    'GLU_TESS_MISSING_END_CONTOUR',
    'GLU_TESS_MISSING_END_POLYGON',
    'GLU_TESS_NEED_COMBINE_CALLBACK',
    'GLU_TESS_TOLERANCE',
    'GLU_TESS_VERTEX',
    'GLU_TESS_VERTEX_DATA',
    'GLU_TESS_WINDING_ABS_GEQ_TWO',
    'GLU_TESS_WINDING_NEGATIVE',
    'GLU_TESS_WINDING_NONZERO',
    'GLU_TESS_WINDING_ODD',
    'GLU_TESS_WINDING_POSITIVE',
    'GLU_TESS_WINDING_RULE',
    'GLU_TRUE',
    'GLU_UNKNOWN',
    'GLU_U_STEP',
    'GLU_VERSION',
    'GLU_VERSION_1_1',
    'GLU_VERSION_1_2',
    'GLU_VERSION_1_3',
    'GLU_VERTEX',
    'GLU_V_STEP',
    'GLUnurbs',
    'GLUnurbsObj',
    'GLUquadric',
    'GLUquadricObj',
    'GLUtesselator',
    'GLUtesselatorObj',
    'GLUtriangulatorObj',
    'GLboolean',
    'GLdouble',
    'GLenum',
    'GLfloat',
    'GLint',
    'GLsizei',
    'GLubyte',
    'GLvoid',
    '_GLUfuncptr',
    'gluBeginCurve',
    'gluBeginPolygon',
    'gluBeginSurface',
    'gluBeginTrim',
    'gluBuild1DMipmapLevels',
    'gluBuild1DMipmaps',
    'gluBuild2DMipmapLevels',
    'gluBuild2DMipmaps',
    'gluBuild3DMipmapLevels',
    'gluBuild3DMipmaps',
    'gluCheckExtension',
    'gluCylinder',
    'gluDeleteNurbsRenderer',
    'gluDeleteQuadric',
    'gluDeleteTess',
    'gluDisk',
    'gluEndCurve',
    'gluEndPolygon',
    'gluEndSurface',
    'gluEndTrim',
    'gluErrorString',
    'gluGetNurbsProperty',
    'gluGetString',
    'gluGetTessProperty',
    'gluLoadSamplingMatrices',
    'gluLookAt',
    'gluNewNurbsRenderer',
    'gluNewQuadric',
    'gluNewTess',
    'gluNextContour',
    'gluNurbsCallback',
    'gluNurbsCallbackData',
    'gluNurbsCallbackDataEXT',
    'gluNurbsCurve',
    'gluNurbsProperty',
    'gluNurbsSurface',
    'gluOrtho2D',
    'gluPartialDisk',
    'gluPerspective',
    'gluPickMatrix',
    'gluProject',
    'gluPwlCurve',
    'gluQuadricCallback',
    'gluQuadricDrawStyle',
    'gluQuadricNormals',
    'gluQuadricOrientation',
    'gluQuadricTexture',
    'gluScaleImage',
    'gluSphere',
    'gluTessBeginContour',
    'gluTessBeginPolygon',
    'gluTessCallback',
    'gluTessEndContour',
    'gluTessEndPolygon',
    'gluTessNormal',
    'gluTessProperty',
    'gluTessVertex',
    'gluUnProject',
    'gluUnProject4'
]



'''OpenGL extension ARB.window_pos

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.window_pos to provide a more 
Python-friendly API

Overview (from the spec)
	
	In order to set the current raster position to a specific window
	coordinate with the RasterPos command, the modelview matrix, projection
	matrix and viewport must be set very carefully.  Furthermore, if the
	desired window coordinate is outside of the window's bounds one must rely
	on a subtle side-effect of the Bitmap command in order to avoid frustum
	clipping.
	
	This extension provides a set of functions to directly set the current
	raster position in window coordinates, bypassing the modelview matrix, the
	projection matrix and the viewport-to-window mapping.  Furthermore, clip
	testing is not performed, so that the current raster position is always
	valid.
	
	This greatly simplifies the process of setting the current raster position
	to a specific window coordinate prior to calling DrawPixels, CopyPixels or
	Bitmap.  Many matrix operations can be avoided when mixing 2D and 3D
	rendering.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/window_pos.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.window_pos import *
from OpenGL.raw.GL.ARB.window_pos import _EXTENSION_NAME

def glInitWindowPosARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glWindowPos2dvARB=wrapper.wrapper(glWindowPos2dvARB).setInputArraySize(
    'v', 2
)
glWindowPos2fvARB=wrapper.wrapper(glWindowPos2fvARB).setInputArraySize(
    'v', 2
)
glWindowPos2ivARB=wrapper.wrapper(glWindowPos2ivARB).setInputArraySize(
    'v', 2
)
glWindowPos2svARB=wrapper.wrapper(glWindowPos2svARB).setInputArraySize(
    'v', 2
)
glWindowPos3dvARB=wrapper.wrapper(glWindowPos3dvARB).setInputArraySize(
    'v', 3
)
glWindowPos3fvARB=wrapper.wrapper(glWindowPos3fvARB).setInputArraySize(
    'v', 3
)
glWindowPos3ivARB=wrapper.wrapper(glWindowPos3ivARB).setInputArraySize(
    'v', 3
)
glWindowPos3svARB=wrapper.wrapper(glWindowPos3svARB).setInputArraySize(
    'v', 3
)
### END AUTOGENERATED SECTION



'''OpenGL extension EXT.blend_func_separate

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.blend_func_separate to provide a more 
Python-friendly API

Overview (from the spec)
	
	Blending capability is extended by defining a function that allows
	independent setting of the RGB and alpha blend factors for blend
	operations that require source and destination blend factors.  It
	is not always desired that the blending used for RGB is also applied
	to alpha.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/blend_func_separate.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.blend_func_separate import *
from OpenGL.raw.GL.EXT.blend_func_separate import _EXTENSION_NAME

def glInitBlendFuncSeparateEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension DFX.texture_compression_FXT1

This module customises the behaviour of the 
OpenGL.raw.GL.DFX.texture_compression_FXT1 to provide a more 
Python-friendly API

Overview (from the spec)
	
	    This extension additional texture compression functionality 's FXT1
	    format, specific to 3dfxsubject to all the requirements and
	    limitations described by the extension GL_ARB_texture_compression.
	    The FXT1 texture format supports only 2D and 3D images without
	    borders.
	
	    Because 3dfx expects to make continual improvement to its FXT1
	    compressor implementation, 3dfx recommends that to achieve best
	    visual quality applications adopt the following procedure with
	    respect to reuse of textures compressed by the GL:
	
		1) Save the RENDERER and VERSION strings along with images
		   compressed by the GL;
		2) Before reuse of the textures, compare the stored strings with
		   strings newly returned from the current GL;
		3) If out-of-date, repeat the compression and storage steps.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/DFX/texture_compression_FXT1.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.DFX.texture_compression_FXT1 import *
from OpenGL.raw.GL.DFX.texture_compression_FXT1 import _EXTENSION_NAME

def glInitTextureCompressionFxt1DFX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension HP.texture_lighting

This module customises the behaviour of the 
OpenGL.raw.GL.HP.texture_lighting to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a mechanism for applications to request
	that color originating from specular lighting be added to
	the fragment color _after_ texture application.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/HP/texture_lighting.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.HP.texture_lighting import *
from OpenGL.raw.GL.HP.texture_lighting import _EXTENSION_NAME

def glInitTextureLightingHP():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.shadow

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.shadow to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines two new operations to be performed on texture
	values before they are passed on to the filtering subsystem.  These
	operations perform either a <= or >= test on the value from texture
	memory and the iterated R value, and return 1.0 or 0.0 if the test
	passes or fails, respectively.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/shadow.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.shadow import *
from OpenGL.raw.GL.SGIX.shadow import _EXTENSION_NAME

def glInitShadowSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.vertex_shader

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.vertex_shader to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_vertex_shader adds a flexible way to change the per-vertex
	processing in the GL pipeline. It provides a method to replace
	the fixed vertex/normal transform and lighting with a user
	specified means of generating processed vertices, texture
	coordinates, color, and secondary color, along with a primitive's
	associated state.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/vertex_shader.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.vertex_shader import *
from OpenGL.raw.GL.EXT.vertex_shader import _EXTENSION_NAME

def glInitVertexShaderEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glSetInvariantEXT.addr size not checked against 'id,type'
glSetInvariantEXT=wrapper.wrapper(glSetInvariantEXT).setInputArraySize(
    'addr', None
)
# INPUT glSetLocalConstantEXT.addr size not checked against 'id,type'
glSetLocalConstantEXT=wrapper.wrapper(glSetLocalConstantEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantbvEXT.addr size not checked against 'id'
glVariantbvEXT=wrapper.wrapper(glVariantbvEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantsvEXT.addr size not checked against 'id'
glVariantsvEXT=wrapper.wrapper(glVariantsvEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantivEXT.addr size not checked against 'id'
glVariantivEXT=wrapper.wrapper(glVariantivEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantfvEXT.addr size not checked against 'id'
glVariantfvEXT=wrapper.wrapper(glVariantfvEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantdvEXT.addr size not checked against 'id'
glVariantdvEXT=wrapper.wrapper(glVariantdvEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantubvEXT.addr size not checked against 'id'
glVariantubvEXT=wrapper.wrapper(glVariantubvEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantusvEXT.addr size not checked against 'id'
glVariantusvEXT=wrapper.wrapper(glVariantusvEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantuivEXT.addr size not checked against 'id'
glVariantuivEXT=wrapper.wrapper(glVariantuivEXT).setInputArraySize(
    'addr', None
)
# INPUT glVariantPointerEXT.addr size not checked against 'id,type,stride'
glVariantPointerEXT=wrapper.wrapper(glVariantPointerEXT).setInputArraySize(
    'addr', None
)
glGetVariantBooleanvEXT=wrapper.wrapper(glGetVariantBooleanvEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetVariantIntegervEXT=wrapper.wrapper(glGetVariantIntegervEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetVariantFloatvEXT=wrapper.wrapper(glGetVariantFloatvEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetVariantPointervEXT=wrapper.wrapper(glGetVariantPointervEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetInvariantBooleanvEXT=wrapper.wrapper(glGetInvariantBooleanvEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetInvariantIntegervEXT=wrapper.wrapper(glGetInvariantIntegervEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetInvariantFloatvEXT=wrapper.wrapper(glGetInvariantFloatvEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetLocalConstantBooleanvEXT=wrapper.wrapper(glGetLocalConstantBooleanvEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetLocalConstantIntegervEXT=wrapper.wrapper(glGetLocalConstantIntegervEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
glGetLocalConstantFloatvEXT=wrapper.wrapper(glGetLocalConstantFloatvEXT).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='id',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.flush_raster

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.flush_raster to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extensions provides a way to ensure that all raster operations 
	currently in the pipeline will be completed before the next 
	raster operation begins. We define a raster operation as an operation
	that involves the rasterization stage of the OpenGL pipeline.
	The implementation is free to decide what consitutes flushing the
	raster subsystem.
	
	The motivation is to allow accurate instrumentation by 
	including this call before stopping rasterization measurements.
	There are cases where Finish() is used, but a FlushRaster()
	would suffice, so this extension is deliberately kept independent 
	of the instruments extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/flush_raster.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.flush_raster import *
from OpenGL.raw.GL.SGIX.flush_raster import _EXTENSION_NAME

def glInitFlushRasterSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Wrapper/Implementation of the GLU quadrics object for PyOpenGL"""
from OpenGL.raw import GLU as _simple
from OpenGL.platform import createBaseFunction, PLATFORM
import ctypes

class GLUQuadric( _simple.GLUquadric ):
    """Implementation class for GLUQuadric classes in PyOpenGL"""
    FUNCTION_TYPE = PLATFORM.functionTypeFor(PLATFORM.GLU)
    CALLBACK_TYPES = {
        # mapping from "which" GLU enumeration to a ctypes function type
        _simple.GLU_ERROR : FUNCTION_TYPE( None, _simple.GLenum )
    }
    def addCallback( self, which, function ):
        """Register a callback for the quadric object
        
        At the moment only GLU_ERROR is supported by OpenGL, but
        we allow for the possibility of more callbacks in the future...
        """
        callbackType = self.CALLBACK_TYPES.get( which )
        if not callbackType:
            raise ValueError(
                """Don't have a registered callback type for %r"""%(
                    which,
                )
            )
        if not isinstance( function, callbackType ):
            cCallback = callbackType( function )
        else:
            cCallback = function
        PLATFORM.GLU.gluQuadricCallback( self, which, cCallback )
        # XXX catch errors!
        if getattr( self, 'callbacks', None ) is None:
            self.callbacks = {}
        self.callbacks[ which ] = cCallback
        return cCallback
GLUquadric = GLUQuadric

def gluQuadricCallback( quadric, which=_simple.GLU_ERROR, function=None ):
    """Set the GLU error callback function"""
    return quadric.addCallback( which, function )

# Override to produce instances of the sub-class...
gluNewQuadric = createBaseFunction( 
    'gluNewQuadric', dll=PLATFORM.GLU, resultType=ctypes.POINTER(GLUQuadric), 
    argTypes=[],
    doc="""gluNewQuadric(  ) -> GLUQuadric
    
Create a new GLUQuadric object""", 
    argNames=[],
)

__all__ = (
    'gluNewQuadric',
    'gluQuadricCallback',
    'GLUQuadric',
)



'''OpenGL extension VERSION.GL_2_0

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_2_0 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_2_0.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_2_0 import *
from OpenGL.raw.GL.VERSION.GL_2_0 import _EXTENSION_NAME

def glInitGl20VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawBuffers.bufs size not checked against n
glDrawBuffers=wrapper.wrapper(glDrawBuffers).setInputArraySize(
    'bufs', None
)
glGetActiveAttrib=wrapper.wrapper(glGetActiveAttrib).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'name',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'size',size=(1,),orPassIn=True
).setOutput(
    'type',size=(1,),orPassIn=True
)
glGetActiveUniform=wrapper.wrapper(glGetActiveUniform).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'name',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'size',size=(1,),orPassIn=True
).setOutput(
    'type',size=(1,),orPassIn=True
)
# glGetAttachedShaders.obj is OUTPUT without known output size
# INPUT glGetAttachedShaders.shaders size not checked against maxCount
glGetAttachedShaders=wrapper.wrapper(glGetAttachedShaders).setOutput(
    'count',size=(1,),orPassIn=True
).setInputArraySize(
    'shaders', None
)
glGetProgramiv=wrapper.wrapper(glGetProgramiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetProgramInfoLog=wrapper.wrapper(glGetProgramInfoLog).setOutput(
    'infoLog',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
glGetShaderiv=wrapper.wrapper(glGetShaderiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetShaderInfoLog=wrapper.wrapper(glGetShaderInfoLog).setOutput(
    'infoLog',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
glGetShaderSource=wrapper.wrapper(glGetShaderSource).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'source',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
# glGetUniformfv.params is OUTPUT without known output size
# glGetUniformiv.params is OUTPUT without known output size
glGetVertexAttribdv=wrapper.wrapper(glGetVertexAttribdv).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetVertexAttribfv=wrapper.wrapper(glGetVertexAttribfv).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetVertexAttribiv=wrapper.wrapper(glGetVertexAttribiv).setOutput(
    'params',size=(4,),orPassIn=True
)
glGetVertexAttribPointerv=wrapper.wrapper(glGetVertexAttribPointerv).setOutput(
    'pointer',size=(1,),orPassIn=True
)
# INPUT glShaderSource.length size not checked against count
# INPUT glShaderSource.string size not checked against count
glShaderSource=wrapper.wrapper(glShaderSource).setInputArraySize(
    'length', None
).setInputArraySize(
    'string', None
)
# INPUT glUniform1fv.value size not checked against count
glUniform1fv=wrapper.wrapper(glUniform1fv).setInputArraySize(
    'value', None
)
# INPUT glUniform2fv.value size not checked against count*2
glUniform2fv=wrapper.wrapper(glUniform2fv).setInputArraySize(
    'value', None
)
# INPUT glUniform3fv.value size not checked against count*3
glUniform3fv=wrapper.wrapper(glUniform3fv).setInputArraySize(
    'value', None
)
# INPUT glUniform4fv.value size not checked against count*4
glUniform4fv=wrapper.wrapper(glUniform4fv).setInputArraySize(
    'value', None
)
# INPUT glUniform1iv.value size not checked against count
glUniform1iv=wrapper.wrapper(glUniform1iv).setInputArraySize(
    'value', None
)
# INPUT glUniform2iv.value size not checked against count*2
glUniform2iv=wrapper.wrapper(glUniform2iv).setInputArraySize(
    'value', None
)
# INPUT glUniform3iv.value size not checked against count*3
glUniform3iv=wrapper.wrapper(glUniform3iv).setInputArraySize(
    'value', None
)
# INPUT glUniform4iv.value size not checked against count*4
glUniform4iv=wrapper.wrapper(glUniform4iv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2fv.value size not checked against count*4
glUniformMatrix2fv=wrapper.wrapper(glUniformMatrix2fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3fv.value size not checked against count*9
glUniformMatrix3fv=wrapper.wrapper(glUniformMatrix3fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4fv.value size not checked against count*16
glUniformMatrix4fv=wrapper.wrapper(glUniformMatrix4fv).setInputArraySize(
    'value', None
)
glVertexAttrib1dv=wrapper.wrapper(glVertexAttrib1dv).setInputArraySize(
    'v', 1
)
glVertexAttrib1fv=wrapper.wrapper(glVertexAttrib1fv).setInputArraySize(
    'v', 1
)
glVertexAttrib1sv=wrapper.wrapper(glVertexAttrib1sv).setInputArraySize(
    'v', 1
)
glVertexAttrib2dv=wrapper.wrapper(glVertexAttrib2dv).setInputArraySize(
    'v', 2
)
glVertexAttrib2fv=wrapper.wrapper(glVertexAttrib2fv).setInputArraySize(
    'v', 2
)
glVertexAttrib2sv=wrapper.wrapper(glVertexAttrib2sv).setInputArraySize(
    'v', 2
)
glVertexAttrib3dv=wrapper.wrapper(glVertexAttrib3dv).setInputArraySize(
    'v', 3
)
glVertexAttrib3fv=wrapper.wrapper(glVertexAttrib3fv).setInputArraySize(
    'v', 3
)
glVertexAttrib3sv=wrapper.wrapper(glVertexAttrib3sv).setInputArraySize(
    'v', 3
)
glVertexAttrib4Nbv=wrapper.wrapper(glVertexAttrib4Nbv).setInputArraySize(
    'v', 4
)
glVertexAttrib4Niv=wrapper.wrapper(glVertexAttrib4Niv).setInputArraySize(
    'v', 4
)
glVertexAttrib4Nsv=wrapper.wrapper(glVertexAttrib4Nsv).setInputArraySize(
    'v', 4
)
glVertexAttrib4Nubv=wrapper.wrapper(glVertexAttrib4Nubv).setInputArraySize(
    'v', 4
)
glVertexAttrib4Nuiv=wrapper.wrapper(glVertexAttrib4Nuiv).setInputArraySize(
    'v', 4
)
glVertexAttrib4Nusv=wrapper.wrapper(glVertexAttrib4Nusv).setInputArraySize(
    'v', 4
)
glVertexAttrib4bv=wrapper.wrapper(glVertexAttrib4bv).setInputArraySize(
    'v', 4
)
glVertexAttrib4dv=wrapper.wrapper(glVertexAttrib4dv).setInputArraySize(
    'v', 4
)
glVertexAttrib4fv=wrapper.wrapper(glVertexAttrib4fv).setInputArraySize(
    'v', 4
)
glVertexAttrib4iv=wrapper.wrapper(glVertexAttrib4iv).setInputArraySize(
    'v', 4
)
glVertexAttrib4sv=wrapper.wrapper(glVertexAttrib4sv).setInputArraySize(
    'v', 4
)
glVertexAttrib4ubv=wrapper.wrapper(glVertexAttrib4ubv).setInputArraySize(
    'v', 4
)
glVertexAttrib4uiv=wrapper.wrapper(glVertexAttrib4uiv).setInputArraySize(
    'v', 4
)
glVertexAttrib4usv=wrapper.wrapper(glVertexAttrib4usv).setInputArraySize(
    'v', 4
)
# INPUT glVertexAttribPointer.pointer size not checked against 'size,type,stride'
glVertexAttribPointer=wrapper.wrapper(glVertexAttribPointer).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION
import OpenGL
from OpenGL import _configflags
from OpenGL._bytes import bytes, _NULL_8_BYTE, as_8_bit
from OpenGL.raw.GL.ARB.shader_objects import GL_OBJECT_COMPILE_STATUS_ARB as GL_OBJECT_COMPILE_STATUS
from OpenGL.raw.GL.ARB.shader_objects import GL_OBJECT_LINK_STATUS_ARB as GL_OBJECT_LINK_STATUS
from OpenGL.raw.GL.ARB.shader_objects import GL_OBJECT_ACTIVE_UNIFORMS_ARB as GL_OBJECT_ACTIVE_UNIFORMS
from OpenGL.raw.GL.ARB.shader_objects import GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB as GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH
from OpenGL.lazywrapper import lazy as _lazy
from OpenGL.raw.GL import _errors

from OpenGL import converters, error, contextdata
from OpenGL.arrays.arraydatatype import ArrayDatatype, GLenumArray
GL_INFO_LOG_LENGTH = constant.Constant( 'GL_INFO_LOG_LENGTH', 0x8B84 )

glShaderSource = platform.createExtensionFunction(
    'glShaderSource', dll=platform.PLATFORM.GL,
    resultType=None,
    argTypes=(_types.GLhandle, _types.GLsizei, ctypes.POINTER(ctypes.c_char_p), arrays.GLintArray,),
    doc = 'glShaderSource( GLhandle(shaderObj),[bytes(string),...]) -> None',
    argNames = ('shaderObj', 'count', 'string', 'length',),
    extension = _EXTENSION_NAME,
)
conv = converters.StringLengths( name='string' )
glShaderSource = wrapper.wrapper(
    glShaderSource
).setPyConverter(
    'count' # number of strings
).setPyConverter(
    'length' # lengths of strings
).setPyConverter(
    'string', conv.stringArray
).setCResolver(
    'string', conv.stringArrayForC,
).setCConverter(
    'length', conv,
).setCConverter(
    'count', conv.totalCount,
)
try:
    del conv
except NameError as err:
    pass

@_lazy( glGetShaderiv )
def glGetShaderiv( baseOperation, shader, pname, status=None ):
    """Retrieve the integer parameter for the given shader

    shader -- shader ID to query
    pname -- parameter name
    status -- pointer to integer to receive status or None to
        return the parameter as an integer value

    returns
        integer if status parameter is None
        status if status parameter is not None
    """
    if status is None:
        status = arrays.GLintArray.zeros( (1,))
        status[0] = 1
        baseOperation(
            shader, pname, status
        )
        return status[0]
    else:
        baseOperation(
            shader, pname, status
        )
        return status

def _afterCheck( key ):
    """Generate an error-checking function for compilation operations"""
    if key == GL_OBJECT_COMPILE_STATUS:
        getter = glGetShaderiv
    else:
        getter = glGetProgramiv
    def GLSLCheckError(
        result,
        baseOperation=None,
        cArguments=None,
        *args
    ):
        result = _errors._error_checker.glCheckError( result, baseOperation, cArguments, *args )
        status = ctypes.c_int()
        getter( cArguments[0], key, ctypes.byref(status))
        status = status.value
        if not status:
            raise error.GLError(
                result = result,
                baseOperation = baseOperation,
                cArguments = cArguments,
                description= glGetShaderInfoLog( cArguments[0] )
            )
        return result
    return GLSLCheckError

if _configflags.ERROR_CHECKING:
    glCompileShader.errcheck = _afterCheck( GL_OBJECT_COMPILE_STATUS )
if _configflags.ERROR_CHECKING:
    glLinkProgram.errcheck = _afterCheck( GL_OBJECT_LINK_STATUS )
## Not sure why, but these give invalid operation :(
##if glValidateProgram and OpenGL.ERROR_CHECKING:
##	glValidateProgram.errcheck = _afterCheck( GL_OBJECT_VALIDATE_STATUS )

@_lazy( glGetShaderInfoLog )
def glGetShaderInfoLog( baseOperation, obj ):
    """Retrieve the shader's error messages as a Python string

    returns string which is '' if no message
    """
    length = int(glGetShaderiv(obj, GL_INFO_LOG_LENGTH))
    if length > 0:
        log = ctypes.create_string_buffer(length)
        baseOperation(obj, length, None, log)
        return log.value.strip(_NULL_8_BYTE) # null-termination
    return ''
@_lazy( glGetProgramInfoLog )
def glGetProgramInfoLog( baseOperation, obj ):
    """Retrieve the shader program's error messages as a Python string

    returns string which is '' if no message
    """
    length = int(glGetProgramiv(obj, GL_INFO_LOG_LENGTH))
    if length > 0:
        log = ctypes.create_string_buffer(length)
        baseOperation(obj, length, None, log)
        return log.value.strip(_NULL_8_BYTE) # null-termination
    return ''

@_lazy( glGetAttachedShaders )
def glGetAttachedShaders( baseOperation, obj ):
    """Retrieve the attached objects as an array of GLhandle instances"""
    length= glGetProgramiv( obj, GL_ATTACHED_SHADERS )
    if length > 0:
        storage = arrays.GLuintArray.zeros( (length,))
        baseOperation( obj, length, None, storage )
        return storage
    return arrays.GLuintArray.zeros( (0,))


@_lazy( glGetShaderSource )
def glGetShaderSource( baseOperation, obj ):
    """Retrieve the program/shader's source code as a Python string

    returns string which is '' if no source code
    """
    length = int(glGetShaderiv(obj, GL_OBJECT_SHADER_SOURCE_LENGTH))
    if length > 0:
        source = ctypes.create_string_buffer(length)
        baseOperation(obj, length, None, source)
        return source.value.strip(_NULL_8_BYTE) # null-termination
    return ''

@_lazy( glGetActiveUniform )
def glGetActiveUniform(baseOperation,program, index):
    """Retrieve the name, size and type of the uniform of the index in the program"""
    max_index = int(glGetProgramiv( program, GL_OBJECT_ACTIVE_UNIFORMS ))
    length = int(glGetProgramiv( program, GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH))
    if index < max_index and index >= 0:
        if length > 0:
            name = ctypes.create_string_buffer(length)
            size = arrays.GLintArray.zeros( (1,))
            gl_type = arrays.GLenumArray.zeros( (1,))
            namelen = arrays.GLsizeiArray.zeros( (1,))
            baseOperation(program, index, length, namelen, size, gl_type, name)
            return name.value[:int(namelen[0])], size[0], gl_type[0]
        raise ValueError( """No currently specified uniform names""" )
    raise IndexError( 'Index %s out of range 0 to %i' % (index, max_index - 1, ) )

@_lazy( glGetUniformLocation )
def glGetUniformLocation( baseOperation, program, name ):
    """Check that name is a string with a null byte at the end of it"""
    if not name:
        raise ValueError( """Non-null name required""" )
    name = as_8_bit( name )
    if name[-1] != _NULL_8_BYTE:
        name = name + _NULL_8_BYTE
    return baseOperation( program, name )
@_lazy( glGetAttribLocation )
def glGetAttribLocation( baseOperation, program, name ):
    """Check that name is a string with a null byte at the end of it"""
    if not name:
        raise ValueError( """Non-null name required""" )
    
    name = as_8_bit( name )
    if name[-1] != _NULL_8_BYTE:
        name = name + _NULL_8_BYTE
    return baseOperation( program, name )

@_lazy( glVertexAttribPointer )
def glVertexAttribPointer(
    baseOperation, index, size, type,
    normalized, stride, pointer,
):
    """Set an attribute pointer for a given shader (index)

    index -- the index of the generic vertex to bind, see
        glGetAttribLocation for retrieval of the value,
        note that index is a global variable, not per-shader
    size -- number of basic elements per record, 1,2,3, or 4
    type -- enum constant for data-type
    normalized -- whether to perform int to float
        normalization on integer-type values
    stride -- stride in machine units (bytes) between
        consecutive records, normally used to create
        "interleaved" arrays
    pointer -- data-pointer which provides the data-values,
        normally a vertex-buffer-object or offset into the
        same.

    This implementation stores a copy of the data-pointer
    in the contextdata structure in order to prevent null-
    reference errors in the renderer.
    """
    array = ArrayDatatype.asArray( pointer, type )
    key = ('vertex-attrib',index)
    contextdata.setValue( key, array )
    return baseOperation(
        index, size, type,
        normalized, stride,
        ArrayDatatype.voidDataPointer( array )
    )

@_lazy( glDrawBuffers )
def glDrawBuffers( baseOperation, n=None, bufs=None ):
    """glDrawBuffers( bufs ) -> bufs

    Wrapper will calculate n from dims of bufs if only
    one argument is provided...
    """
    if bufs is None:
        bufs = n
        n = None
    bufs = arrays.GLenumArray.asArray( bufs )
    if n is None:
        n = arrays.GLenumArray.arraySize( bufs )
    return baseOperation( n,bufs )



"""Constants for OpenGL.GLE

Automatically generated by the generateraw script, do not edit!
"""

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid



GLE_TEXTURE_ENABLE = Constant( 'GLE_TEXTURE_ENABLE', 65536)
GLE_TEXTURE_NORMAL_CYL = Constant( 'GLE_TEXTURE_NORMAL_CYL', 4)
GLE_TEXTURE_NORMAL_FLAT = Constant( 'GLE_TEXTURE_NORMAL_FLAT', 2)
GLE_TEXTURE_NORMAL_MODEL_CYL = Constant( 'GLE_TEXTURE_NORMAL_MODEL_CYL', 10)
GLE_TEXTURE_NORMAL_MODEL_FLAT = Constant( 'GLE_TEXTURE_NORMAL_MODEL_FLAT', 8)
GLE_TEXTURE_NORMAL_MODEL_SPH = Constant( 'GLE_TEXTURE_NORMAL_MODEL_SPH', 12)
GLE_TEXTURE_NORMAL_SPH = Constant( 'GLE_TEXTURE_NORMAL_SPH', 6)
GLE_TEXTURE_STYLE_MASK = Constant( 'GLE_TEXTURE_STYLE_MASK', 255)
GLE_TEXTURE_VERTEX_CYL = Constant( 'GLE_TEXTURE_VERTEX_CYL', 3)
GLE_TEXTURE_VERTEX_FLAT = Constant( 'GLE_TEXTURE_VERTEX_FLAT', 1)
GLE_TEXTURE_VERTEX_MODEL_CYL = Constant( 'GLE_TEXTURE_VERTEX_MODEL_CYL', 9)
GLE_TEXTURE_VERTEX_MODEL_FLAT = Constant( 'GLE_TEXTURE_VERTEX_MODEL_FLAT', 7)
GLE_TEXTURE_VERTEX_MODEL_SPH = Constant( 'GLE_TEXTURE_VERTEX_MODEL_SPH', 11)
GLE_TEXTURE_VERTEX_SPH = Constant( 'GLE_TEXTURE_VERTEX_SPH', 5)
TUBE_CONTOUR_CLOSED = Constant( 'TUBE_CONTOUR_CLOSED', 4096)
TUBE_JN_ANGLE = Constant( 'TUBE_JN_ANGLE', 2)
TUBE_JN_CAP = Constant( 'TUBE_JN_CAP', 16)
TUBE_JN_CUT = Constant( 'TUBE_JN_CUT', 3)
TUBE_JN_MASK = Constant( 'TUBE_JN_MASK', 15)
TUBE_JN_RAW = Constant( 'TUBE_JN_RAW', 1)
TUBE_JN_ROUND = Constant( 'TUBE_JN_ROUND', 4)
TUBE_NORM_EDGE = Constant( 'TUBE_NORM_EDGE', 512)
TUBE_NORM_FACET = Constant( 'TUBE_NORM_FACET', 256)
TUBE_NORM_MASK = Constant( 'TUBE_NORM_MASK', 3840)
TUBE_NORM_PATH_EDGE = Constant( 'TUBE_NORM_PATH_EDGE', 1024)
__GLE_DOUBLE = Constant( '__GLE_DOUBLE', 1)
__all__ = [
    'GLE_TEXTURE_ENABLE',
    'GLE_TEXTURE_NORMAL_CYL',
    'GLE_TEXTURE_NORMAL_FLAT',
    'GLE_TEXTURE_NORMAL_MODEL_CYL',
    'GLE_TEXTURE_NORMAL_MODEL_FLAT',
    'GLE_TEXTURE_NORMAL_MODEL_SPH',
    'GLE_TEXTURE_NORMAL_SPH',
    'GLE_TEXTURE_STYLE_MASK',
    'GLE_TEXTURE_VERTEX_CYL',
    'GLE_TEXTURE_VERTEX_FLAT',
    'GLE_TEXTURE_VERTEX_MODEL_CYL',
    'GLE_TEXTURE_VERTEX_MODEL_FLAT',
    'GLE_TEXTURE_VERTEX_MODEL_SPH',
    'GLE_TEXTURE_VERTEX_SPH',
    'TUBE_CONTOUR_CLOSED',
    'TUBE_JN_ANGLE',
    'TUBE_JN_CAP',
    'TUBE_JN_CUT',
    'TUBE_JN_MASK',
    'TUBE_JN_RAW',
    'TUBE_JN_ROUND',
    'TUBE_NORM_EDGE',
    'TUBE_NORM_FACET',
    'TUBE_NORM_MASK',
    'TUBE_NORM_PATH_EDGE',
    '__GLE_DOUBLE'
]



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGI_color_matrix'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGI_color_matrix',error_checker=_errors._error_checker)
GL_COLOR_MATRIX_SGI=_C('GL_COLOR_MATRIX_SGI',0x80B1)
GL_COLOR_MATRIX_STACK_DEPTH_SGI=_C('GL_COLOR_MATRIX_STACK_DEPTH_SGI',0x80B2)
GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI=_C('GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI',0x80B3)
GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI',0x80BB)
GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI',0x80B7)
GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI',0x80BA)
GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI',0x80B6)
GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI',0x80B9)
GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI',0x80B5)
GL_POST_COLOR_MATRIX_RED_BIAS_SGI=_C('GL_POST_COLOR_MATRIX_RED_BIAS_SGI',0x80B8)
GL_POST_COLOR_MATRIX_RED_SCALE_SGI=_C('GL_POST_COLOR_MATRIX_RED_SCALE_SGI',0x80B4)




'''OpenGL extension NV.tessellation_program5

This module customises the behaviour of the 
OpenGL.raw.GL.NV.tessellation_program5 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension, in conjunction with the ARB_tessellation_shader extension,
	introduces a new tessellation stage to the OpenGL primitive processing
	pipeline.  The ARB_tessellation_shader extension provides programmable
	shading functionality using the OpenGL Shading Language as its base; this
	extension provides assembly programmable shaders building on the family of
	assembly programmability extensions including ARB_vertex_program,
	ARB_fragment_program, NV_gpu_program4, and NV_geometry_program4.
	
	This extension adds a new basic primitive type, called a patch, which
	consists of an array of vertices plus some associated per-patch state.  It
	also adds two new assembly program types:  a tessellation control program
	that transforms a patch into a new patch and a tessellation evaluation
	program that computes the position and attributes of each vertex produced
	by the tesselator.
	
	When tessellation is active, it begins by running the optional
	tessellation control program, if enabled.  This program consumes a
	variable-size input patch and produces a new fixed-size output patch.  The
	output patch consists of an array of vertices, and a set of per-patch
	attributes.  The per-patch attributes include tessellation levels that
	control how finely the patch will be tessellated.  For each patch
	processed, multiple tessellation control program invocations are performed
	-- one per output patch vertex.  Each tessellation control program
	invocation writes all the attributes of its corresponding output patch
	vertex.  A tessellation control program may also read the per-vertex
	outputs of other tessellation control program invocations, as well as read
	and write shared per-patch outputs.  The tessellation control program
	invocations for a single patch effectively run as a group.  The GL
	automatically synchronizes threads to ensure that when executing a given
	instruction, all previous instructions have completed for all program
	invocations in the group.
	
	The tessellation primitive generator then decomposes a patch into a new
	set of primitives using the tessellation levels to determine how finely
	tessellated the output should be.  The primitive generator begins with
	either a triangle or a quad, and splits each outer edge of the primitive
	into a number of segments approximately equal to the corresponding element
	of the outer tessellation level array.  The interior of the primitive is
	tessellated according to elements of the inner tessellation level array.
	The primitive generator has three modes:  TRIANGLES and QUADS split a
	triangular or quad-shaped patch into a set of triangles that cover the
	original patch; ISOLINES_NV splits a quad-shaped patch into a set of line
	strips spanning the patch.  Each vertex generated by the tessellation
	primitive generator is assigned a (u,v) or (u,v,w) coordinate indicating
	its relative location in the subdivided triangle or quad.
	
	For each vertex produced by the tessellation primitive generator, the
	tessellation evaluation program is run to compute its position and other
	attributes of the vertex, using its (u,v) or (u,v,w) coordinate.  When
	computing the final vertex attributes, the tessellation evaluation program
	can also read the attributes of any of the vertices of the patch written
	by the tessellation control program.  Tessellation evaluation program
	invocations are completely independent, although all invocations for a
	single patch share the same collection of input vertices and per-patch
	attributes.
	
	The tessellator operates on vertices after they have been transformed by a
	vertex program or fixed-function vertex processing.  The primitives
	generated by the tessellator are passed further down the OpenGL pipeline,
	where they can be used as inputs to geometry programs, transform feedback,
	and the rasterizer.
	
	The tessellation control and evaluation programs are both optional.  If
	neither program type is present, the tessellation stage has no effect.  If
	no tessellation control program is present, the input patch provided by
	the application is passed directly to the tessellation primitive
	generator, and a set of fixed tessellation level parameters (specified via
	the PatchParameterfv function) is used to control primitive generation.
	If no tessellation evaluation program is present, the output patch
	produced by the tessellation control program is passed as a patch to
	subsequent pipeline stages, where it can be consumed by geometry programs,
	transform feedback, or the rasterizer.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/tessellation_program5.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.tessellation_program5 import *
from OpenGL.raw.GL.NV.tessellation_program5 import _EXTENSION_NAME

def glInitTessellationProgram5NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Implementation of OpenGL constant objects"""
import sys
from OpenGL._bytes import bytes,unicode,as_8_bit, long, integer_types, maxsize
from OpenGL import _configflags

class Constant( object ):
    """OpenGL constant that displays itself as a name rather than a value

    The purpose of this class is to make debugging OpenGL code easier,
    as you recieve messages that say what value you passed in in a
    human-readable form, rather than as a bald number that requires
    lookup and disambiguation in the header file.
    """
    def __new__( cls, name, value=None ):
        """Initialise the constant with the given name and value"""
        if not isinstance( value, Constant ):
            if isinstance( value, float ) and cls is not FloatConstant:
                return FloatConstant( name, value )
            elif isinstance( value, int ) and cls is not IntConstant:
                return IntConstant( name, value )
            elif isinstance( value, long ) and cls is not LongConstant:
                return LongConstant( name, value )
            elif isinstance( value, (bytes,unicode) ) and cls is not StringConstant:
                return StringConstant( name, as_8_bit(value) )
        if isinstance( value, integer_types ):
            if value > maxsize: # TODO: I'm guessing this should really by sizeof GLint, not 
                value = - (value & maxsize)
        base = super(Constant,cls).__new__( cls, value )
        base.name = name
        if _configflags.MODULE_ANNOTATIONS:
            frame = sys._getframe().f_back
            if frame and frame.f_back and '__name__' in frame.f_back.f_globals:
                base.__module__ = frame.f_back.f_globals['__name__']
        return base
    def __repr__( self ):
        """Return the name, rather than the bald value"""
        return self.name
    def __getnewargs__( self ):
        """Produce the new arguments for recreating the instance"""
        return (self.name,) + super( Constant, self ).__getnewargs__()

class NumericConstant( Constant ):
    """Base class for numeric-value constants"""
    def __str__( self ):
        """Return the value as a human-friendly string"""
        return '%s (%s)'%(self.name,super(Constant,self).__str__())
    def __getstate__(self):
        """Retrieve state for pickle and the like"""
        return self.name
    def __setstate__( self, state ):
        self.name = state

class IntConstant( NumericConstant, int ):
    """Integer constant"""
if int is not long:
    class LongConstant( NumericConstant, long ):
        """Long integer constant"""
else:
    LongConstant = IntConstant
class FloatConstant( NumericConstant, float ):
    """Float constant"""

class StringConstant( Constant, bytes ):
    """String constants"""
    def __repr__( self ):
        """Return the value as a human-friendly string"""
        return '%s (%s)'%(self.name,super(Constant,self).__str__())

if __name__ == "__main__":
    x = IntConstant( 'testint', 3 )
    y = FloatConstant( 'testfloat', 3.0 )
    z = StringConstant( 'teststr', 'some testing string' )

    import pickle
    for val in x,y,z:
        restored = pickle.loads( pickle.dumps( val ))
        assert restored == val, (str(restored),str(val))
        assert restored.name == val.name, (restored.name,val.name)



'''OpenGL extension ATI.texture_env_combine3

This module customises the behaviour of the 
OpenGL.raw.GL.ATI.texture_env_combine3 to provide a more 
Python-friendly API

Overview (from the spec)
	
	Adds new set of operations to the texture combiner operations.
	
	MODULATE_ADD_ATI               Arg0 * Arg2 + Arg1
	MODULATE_SIGNED_ADD_ATI        Arg0 * Arg2 + Arg1 - 0.5
	MODULATE_SUBTRACT_ATI          Arg0 * Arg2 - Arg1
	
	where Arg0, Arg1 and Arg2 are derived from
	
	    PRIMARY_COLOR_ARB       primary color of incoming fragment
	    TEXTURE                 texture color of corresponding texture unit
	    CONSTANT_ARB            texture environment constant color
	    PREVIOUS_ARB            result of previous texture environment; on
	                            texture unit 0, this maps to PRIMARY_COLOR_ARB
	
	In addition, the result may be scaled by 1.0, 2.0 or 4.0.
	
	Note that in addition to providing more flexible equations new source 
	inputs have been added for zero and one.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ATI/texture_env_combine3.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ATI.texture_env_combine3 import *
from OpenGL.raw.GL.ATI.texture_env_combine3 import _EXTENSION_NAME

def glInitTextureEnvCombine3ATI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_ARB_buffer_region'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_ARB_buffer_region',error_checker=_errors._error_checker)
WGL_BACK_COLOR_BUFFER_BIT_ARB=_C('WGL_BACK_COLOR_BUFFER_BIT_ARB',0x00000002)
WGL_DEPTH_BUFFER_BIT_ARB=_C('WGL_DEPTH_BUFFER_BIT_ARB',0x00000004)
WGL_FRONT_COLOR_BUFFER_BIT_ARB=_C('WGL_FRONT_COLOR_BUFFER_BIT_ARB',0x00000001)
WGL_STENCIL_BUFFER_BIT_ARB=_C('WGL_STENCIL_BUFFER_BIT_ARB',0x00000008)
@_f
@_p.types(_cs.HANDLE,_cs.HDC,_cs.c_int,_cs.UINT)
def wglCreateBufferRegionARB(hDC,iLayerPlane,uType):pass
@_f
@_p.types(_cs.VOID,_cs.HANDLE)
def wglDeleteBufferRegionARB(hRegion):pass
@_f
@_p.types(_cs.BOOL,_cs.HANDLE,_cs.c_int,_cs.c_int,_cs.c_int,_cs.c_int,_cs.c_int,_cs.c_int)
def wglRestoreBufferRegionARB(hRegion,x,y,width,height,xSrc,ySrc):pass
@_f
@_p.types(_cs.BOOL,_cs.HANDLE,_cs.c_int,_cs.c_int,_cs.c_int,_cs.c_int)
def wglSaveBufferRegionARB(hRegion,x,y,width,height):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_NV_float_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_NV_float_buffer',error_checker=_errors._error_checker)
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGBA_NV=_C('WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGBA_NV',0x20B4)
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGB_NV=_C('WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RGB_NV',0x20B3)
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RG_NV=_C('WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_RG_NV',0x20B2)
WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_R_NV=_C('WGL_BIND_TO_TEXTURE_RECTANGLE_FLOAT_R_NV',0x20B1)
WGL_FLOAT_COMPONENTS_NV=_C('WGL_FLOAT_COMPONENTS_NV',0x20B0)
WGL_TEXTURE_FLOAT_RGBA_NV=_C('WGL_TEXTURE_FLOAT_RGBA_NV',0x20B8)
WGL_TEXTURE_FLOAT_RGB_NV=_C('WGL_TEXTURE_FLOAT_RGB_NV',0x20B7)
WGL_TEXTURE_FLOAT_RG_NV=_C('WGL_TEXTURE_FLOAT_RG_NV',0x20B6)
WGL_TEXTURE_FLOAT_R_NV=_C('WGL_TEXTURE_FLOAT_R_NV',0x20B5)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_texture_norm16'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_texture_norm16',error_checker=_errors._error_checker)
GL_R16_EXT=_C('GL_R16_EXT',0x822A)
GL_R16_SNORM_EXT=_C('GL_R16_SNORM_EXT',0x8F98)
GL_RG16_EXT=_C('GL_RG16_EXT',0x822C)
GL_RG16_SNORM_EXT=_C('GL_RG16_SNORM_EXT',0x8F99)
GL_RGB16_EXT=_C('GL_RGB16_EXT',0x8054)
GL_RGB16_SNORM_EXT=_C('GL_RGB16_SNORM_EXT',0x8F9A)
GL_RGBA16_EXT=_C('GL_RGBA16_EXT',0x805B)
GL_RGBA16_SNORM_EXT=_C('GL_RGBA16_SNORM_EXT',0x8F9B)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture_shared_exponent'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture_shared_exponent',error_checker=_errors._error_checker)
GL_RGB9_E5_EXT=_C('GL_RGB9_E5_EXT',0x8C3D)
GL_TEXTURE_SHARED_SIZE_EXT=_C('GL_TEXTURE_SHARED_SIZE_EXT',0x8C3F)
GL_UNSIGNED_INT_5_9_9_9_REV_EXT=_C('GL_UNSIGNED_INT_5_9_9_9_REV_EXT',0x8C3E)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_rg'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_rg',error_checker=_errors._error_checker)
GL_R16=_C('GL_R16',0x822A)
GL_R16F=_C('GL_R16F',0x822D)
GL_R16I=_C('GL_R16I',0x8233)
GL_R16UI=_C('GL_R16UI',0x8234)
GL_R32F=_C('GL_R32F',0x822E)
GL_R32I=_C('GL_R32I',0x8235)
GL_R32UI=_C('GL_R32UI',0x8236)
GL_R8=_C('GL_R8',0x8229)
GL_R8I=_C('GL_R8I',0x8231)
GL_R8UI=_C('GL_R8UI',0x8232)
GL_RG=_C('GL_RG',0x8227)
GL_RG16=_C('GL_RG16',0x822C)
GL_RG16F=_C('GL_RG16F',0x822F)
GL_RG16I=_C('GL_RG16I',0x8239)
GL_RG16UI=_C('GL_RG16UI',0x823A)
GL_RG32F=_C('GL_RG32F',0x8230)
GL_RG32I=_C('GL_RG32I',0x823B)
GL_RG32UI=_C('GL_RG32UI',0x823C)
GL_RG8=_C('GL_RG8',0x822B)
GL_RG8I=_C('GL_RG8I',0x8237)
GL_RG8UI=_C('GL_RG8UI',0x8238)
GL_RG_INTEGER=_C('GL_RG_INTEGER',0x8228)




'''OpenGL extension AMD.vertex_shader_layer

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.vertex_shader_layer to provide a more 
Python-friendly API

Overview (from the spec)
	
	The gl_Layer built-in shading language variable was introduced with the
	ARB_geometry_shader extension and subsequently promoted to core OpenGL
	in version 3.2. This variable is an output from the geometry shader stage
	that allows rendering to be directed to a specific layer of an array
	texture, slice of a 3D texture or face of a cube map or cube map array
	attachment of the framebuffer. Thus, this extremely useful functionality is
	only available if a geometry shader is present - even if the geometry shader
	is not otherwise required by the application. This adds overhead to the
	graphics processing pipeline, and complexity to applications. It also
	precludes implementations that cannot support geometry shaders from
	supporting rendering to layered framebuffer attachments.
	
	This extension exposes the gl_Layer built-in variable in the vertex shader,
	allowing rendering to be directed to layered framebuffer attachments with
	only a vertex and fragment shader present. Combined with features such
	as instancing, or static vertex attributes and so on, this allows a wide
	variety of techniques to be implemented without the requirement for a
	geometry shader to be present.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/vertex_shader_layer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.vertex_shader_layer import *
from OpenGL.raw.GL.AMD.vertex_shader_layer import _EXTENSION_NAME

def glInitVertexShaderLayerAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_transform_feedback'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_transform_feedback',error_checker=_errors._error_checker)
GL_ACTIVE_VARYINGS_NV=_C('GL_ACTIVE_VARYINGS_NV',0x8C81)
GL_ACTIVE_VARYING_MAX_LENGTH_NV=_C('GL_ACTIVE_VARYING_MAX_LENGTH_NV',0x8C82)
GL_BACK_PRIMARY_COLOR_NV=_C('GL_BACK_PRIMARY_COLOR_NV',0x8C77)
GL_BACK_SECONDARY_COLOR_NV=_C('GL_BACK_SECONDARY_COLOR_NV',0x8C78)
GL_CLIP_DISTANCE_NV=_C('GL_CLIP_DISTANCE_NV',0x8C7A)
GL_GENERIC_ATTRIB_NV=_C('GL_GENERIC_ATTRIB_NV',0x8C7D)
GL_INTERLEAVED_ATTRIBS_NV=_C('GL_INTERLEAVED_ATTRIBS_NV',0x8C8C)
GL_LAYER_NV=_C('GL_LAYER_NV',0x8DAA)
GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_NV=_C('GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS_NV',0x8C8A)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_NV=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS_NV',0x8C8B)
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_NV=_C('GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS_NV',0x8C80)
GL_NEXT_BUFFER_NV=_C('GL_NEXT_BUFFER_NV',-2)
GL_PRIMITIVES_GENERATED_NV=_C('GL_PRIMITIVES_GENERATED_NV',0x8C87)
GL_PRIMITIVE_ID_NV=_C('GL_PRIMITIVE_ID_NV',0x8C7C)
GL_RASTERIZER_DISCARD_NV=_C('GL_RASTERIZER_DISCARD_NV',0x8C89)
GL_SEPARATE_ATTRIBS_NV=_C('GL_SEPARATE_ATTRIBS_NV',0x8C8D)
GL_SKIP_COMPONENTS1_NV=_C('GL_SKIP_COMPONENTS1_NV',-6)
GL_SKIP_COMPONENTS2_NV=_C('GL_SKIP_COMPONENTS2_NV',-5)
GL_SKIP_COMPONENTS3_NV=_C('GL_SKIP_COMPONENTS3_NV',-4)
GL_SKIP_COMPONENTS4_NV=_C('GL_SKIP_COMPONENTS4_NV',-3)
GL_TEXTURE_COORD_NV=_C('GL_TEXTURE_COORD_NV',0x8C79)
GL_TRANSFORM_FEEDBACK_ATTRIBS_NV=_C('GL_TRANSFORM_FEEDBACK_ATTRIBS_NV',0x8C7E)
GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_NV=_C('GL_TRANSFORM_FEEDBACK_BUFFER_BINDING_NV',0x8C8F)
GL_TRANSFORM_FEEDBACK_BUFFER_MODE_NV=_C('GL_TRANSFORM_FEEDBACK_BUFFER_MODE_NV',0x8C7F)
GL_TRANSFORM_FEEDBACK_BUFFER_NV=_C('GL_TRANSFORM_FEEDBACK_BUFFER_NV',0x8C8E)
GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_NV=_C('GL_TRANSFORM_FEEDBACK_BUFFER_SIZE_NV',0x8C85)
GL_TRANSFORM_FEEDBACK_BUFFER_START_NV=_C('GL_TRANSFORM_FEEDBACK_BUFFER_START_NV',0x8C84)
GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_NV=_C('GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN_NV',0x8C88)
GL_TRANSFORM_FEEDBACK_RECORD_NV=_C('GL_TRANSFORM_FEEDBACK_RECORD_NV',0x8C86)
GL_TRANSFORM_FEEDBACK_VARYINGS_NV=_C('GL_TRANSFORM_FEEDBACK_VARYINGS_NV',0x8C83)
GL_VERTEX_ID_NV=_C('GL_VERTEX_ID_NV',0x8C7B)
@_f
@_p.types(None,_cs.GLuint,arrays.GLcharArray)
def glActiveVaryingNV(program,name):pass
@_f
@_p.types(None,_cs.GLenum)
def glBeginTransformFeedbackNV(primitiveMode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint)
def glBindBufferBaseNV(target,index,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLintptr)
def glBindBufferOffsetNV(target,index,buffer,offset):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLintptr,_cs.GLsizeiptr)
def glBindBufferRangeNV(target,index,buffer,offset,size):pass
@_f
@_p.types(None,)
def glEndTransformFeedbackNV():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLcharArray)
def glGetActiveVaryingNV(program,index,bufSize,length,size,type,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLintArray)
def glGetTransformFeedbackVaryingNV(program,index,location):pass
@_f
@_p.types(_cs.GLint,_cs.GLuint,arrays.GLcharArray)
def glGetVaryingLocationNV(program,name):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLintArray,_cs.GLenum)
def glTransformFeedbackAttribsNV(count,attribs,bufferMode):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLintArray,_cs.GLsizei,arrays.GLintArray,_cs.GLenum)
def glTransformFeedbackStreamAttribsNV(count,attribs,nbuffers,bufstreams,bufferMode):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLintArray,_cs.GLenum)
def glTransformFeedbackVaryingsNV(program,count,locations,bufferMode):pass



'''OpenGL extension ARB.shader_group_vote

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shader_group_vote to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides new built-in functions to compute the composite of
	a set of boolean conditions across a group of shader invocations.  These
	composite results may be used to execute shaders more efficiently on a
	single-instruction multiple-data (SIMD) processor.  The set of shader
	invocations across which boolean conditions are evaluated is
	implementation-dependent, and this extension provides no guarantee over
	how individual shader invocations are assigned to such sets.  In
	particular, the set of shader invocations has no necessary relationship
	with the compute shader local work group -- a pair of shader invocations
	in a single compute shader work group may end up in different sets used by
	these built-ins.
	
	Compute shaders operate on an explicitly specified group of threads (a
	local work group), but many implementations of OpenGL 4.3 will even group
	non-compute shader invocations and execute them in a SIMD fashion.  When
	executing code like
	
	  if (condition) {
	    result = do_fast_path();
	  } else {
	    result = do_general_path();
	  }
	
	where <condition> diverges between invocations, a SIMD implementation
	might first call do_fast_path() for the invocations where <condition> is
	true and leave the other invocations dormant.  Once do_fast_path()
	returns, it might call do_general_path() for invocations where <condition>
	is false and leave the other invocations dormant.  In this case, the
	shader executes *both* the fast and the general path and might be better
	off just using the general path for all invocations.
	
	This extension provides the ability to avoid divergent execution by
	evaluting a condition across an entire SIMD invocation group using code
	like:
	
	  if (allInvocationsARB(condition)) {
	    result = do_fast_path();
	  } else {
	    result = do_general_path();
	  }
	
	The built-in function allInvocationsARB() will return the same value for
	all invocations in the group, so the group will either execute
	do_fast_path() or do_general_path(), but never both.  For example, shader
	code might want to evaluate a complex function iteratively by starting
	with an approximation of the result and then refining the approximation.
	Some input values may require a small number of iterations to generate an
	accurate result (do_fast_path) while others require a larger number
	(do_general_path).  In another example, shader code might want to evaluate
	a complex function (do_general_path) that can be greatly simplified when
	assuming a specific value for one of its inputs (do_fast_path).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shader_group_vote.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shader_group_vote import *
from OpenGL.raw.GL.ARB.shader_group_vote import _EXTENSION_NAME

def glInitShaderGroupVoteARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.draw_buffers

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.draw_buffers to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/draw_buffers.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.draw_buffers import *
from OpenGL.raw.GLES2.NV.draw_buffers import _EXTENSION_NAME

def glInitDrawBuffersNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawBuffersNV.bufs size not checked against n
glDrawBuffersNV=wrapper.wrapper(glDrawBuffersNV).setInputArraySize(
    'bufs', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.object_purgeable

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.object_purgeable to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the ability to mark the storage of OpenGL
	objects as "purgeable".
	
	Many of today's modern virtual memory systems include the concept of
	purgeability in order to avoid unnecessary paging when the object
	contents are no longer needed.  In OpenGL, objects such as textures,
	vertex buffers, pixel buffers, and renderbuffers all have
	significant storage requirements.  By default, the OpenGL is
	required to preserve the contents of these objects regardless of
	system resource stress, such as vram shortage or physical memory
	shortage.  Often this is accomplished by temporarily paging the
	contents of objects that are not currently needed to some kind of
	secondary storage area.  This paging operation can be an unnecessary
	computational expense in the cases where the data is not going to be
	used again or where the content can be reproduced by the application
	with less expense than the paging operation would require.
	
	This extension defines a mechanism for the application to mark the
	storage of OpenGL objects as "purgeable" in order to influence these
	paging operations.  The application can further control the
	semantics of making object storage "purgeable" with two options
	("volatile" and "released") and "unpurgeable" with two options
	("undefined" and "retained")
	
	Applications that use this extension will typically follow one of
	two operational models.  The typical model for most applications is
	to mark an object storage as "purgeable" with the "volatile" option,
	and then later mark the storage as "unpurgeable" with the "retained"
	option. When this happens, the application may or may not need to
	respecify the object contents, depending on the whether the object
	storage was actually released.  The application can find out whether
	the storage was released by examining the return value of the
	function which marks the storage as "unpurgeable".  This model is
	useful when the application does not know at the time it marks the
	object storage as "purgeable" whether it will later need those
	contents to be valid.
	
	Another operational model is for an application to mark the storage
	for an object as "purgeable" with the "released" option, and then
	later mark the object "unpurgeable" with the "undefined" option.  In
	this latter model, the application intends to unconditionally reload
	the object contents later on, and so it tells the GL that it is okay
	if the contents are "undefined" when the storage is re-allocated.
	
	Note that in both models, it is possible for the contents to become
	undefined since they could have actually been purged from the system
	in either case.  The various options are still useful, however,
	since they give more information to the GL about what the
	application expects to happen and the GL can use this information to
	make better predictions about which paging choices will be more
	efficient.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/object_purgeable.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.object_purgeable import *
from OpenGL.raw.GL.APPLE.object_purgeable import _EXTENSION_NAME

def glInitObjectPurgeableAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetObjectParameterivAPPLE=wrapper.wrapper(glGetObjectParameterivAPPLE).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_swizzle

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_swizzle to provide a more 
Python-friendly API

Overview (from the spec)
	
	Classic OpenGL texture formats conflate texture storage and
	interpretation, and assume that textures represent color. In 
	modern applications, a significant quantity of textures don't
	represent color, but rather data like shadow maps, normal maps,
	page tables, occlusion data, etc.. For the latter class of data,
	calling the data "RGBA" is just a convenient mapping of what the
	data is onto the current model, but isn't an accurate reflection
	of the reality of the data.
	
	The existing texture formats provide an almost orthogonal set of
	data types, sizes, and number of components, but the mappings of 
	this storage into what the shader or fixed-function pipeline 
	fetches is very much non-orthogonal. Previous extensions have
	added some of the most demanded missing formats, but the problem
	has not been solved once and for all.
	
	This extension provides a mechanism to swizzle the components 
	of a texture before they are applied according to the texture
	environment in fixed-function or as they are returned to the 
	shader.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_swizzle.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_swizzle import *
from OpenGL.raw.GL.ARB.texture_swizzle import _EXTENSION_NAME

def glInitTextureSwizzleARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.indirect_parameters

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.indirect_parameters to provide a more 
Python-friendly API

Overview (from the spec)
	
	    OpenGL 4.3 (with the introduction of the GL_ARB_multi_draw_indirect
	extension) enhanced the ability of OpenGL to allow a large sets of
	parameters for indirect draws (introduced with OpenGL 4.0) into a buffer
	object and dispatch the entire list with one API call. This allows, for
	example, a shader (such as a compute shader via shader storage buffers,
	or a geometry shader via transform feedback) to produce lists of draw
	commands that can then be consumed by OpenGL without a server-client
	round trip. However, when a variable and potentially unknown number of
	draws are produced by such a shader, it becomes difficult to know how
	many draws are in the output array(s). Applications must resort to
	techniques such as transform feedback primitive queries, or mapping
	buffers containing the content of atomic counters, which can cause stalls
	or bubbles in the OpenGL pipeline.
	
	    This extension introduces the concept of the "parameter buffer", which
	is a target allowing buffers to store parameters for certain drawing
	commands. Also in this extension, new variants of MultiDrawArraysIndirect
	and MultiDrawElementsIndirect are introduced that source some of their
	parameters from this buffer. Further commands could potentially be
	introduced that source other parameters from a buffer.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/indirect_parameters.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.indirect_parameters import *
from OpenGL.raw.GL.ARB.indirect_parameters import _EXTENSION_NAME

def glInitIndirectParametersARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_multisample

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides support for two new types of "multisample
	textures" - two-dimensional and two-dimensional array - as well as
	mechanisms to fetch a specific sample from such a texture in a shader,
	and to attach such textures to FBOs for rendering.
	
	This extension also includes the following functionality, first described
	in NV_explicit_multisample:
	
	 * A query in the API to query the location of samples within the pixel
	
	 * An explicit control for the multisample sample mask to augment the
	   control provided by SampleCoverage

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_multisample import *
from OpenGL.raw.GL.ARB.texture_multisample import _EXTENSION_NAME

def glInitTextureMultisampleARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetMultisamplefv=wrapper.wrapper(glGetMultisamplefv).setOutput(
    'val',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.explicit_multisample

This module customises the behaviour of the 
OpenGL.raw.GL.NV.explicit_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	In traditional multisample specs, the API only allows access to the samples
	indirectly through methods such as coverage values and downsampled
	readbacks. NV_explicit_multisample adds a set of new capabilities to allow
	more precise control over the use of multisamples. Specifically, it adds:
	
	 * A query in the API to query the location of samples within the pixel
	
	 * An explicit control for the multisample sample mask to augment the
	   control provided by SampleCoverage
	
	 * A new texture target to wrap a renderbuffer and allow a restricted class
	   of accesses to the samples
	
	 * The ability to fetch a specific sample from a multisampled texture from
	   within a shader
	
	 * A program option to enable the new behavior

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/explicit_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.explicit_multisample import *
from OpenGL.raw.GL.NV.explicit_multisample import _EXTENSION_NAME

def glInitExplicitMultisampleNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetMultisamplefvNV=wrapper.wrapper(glGetMultisamplefvNV).setOutput(
    'val',size=(2,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.present_video

This module customises the behaviour of the 
OpenGL.raw.GL.NV.present_video to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for displaying textures and
	renderbuffers on auxiliary video output devices.  It allows an
	application to specify separate buffers for the individual
	fields used with interlaced output.  It also provides a way
	to present frames or field pairs simultaneously in two separate
	video streams.  It also allows an application to request when images
	should be displayed, and to obtain feedback on exactly when images
	are actually first displayed.
	
	This specification attempts to avoid language that would tie it to
	any particular hardware or vendor.  However, it should be noted that
	it has been designed specifically for use with NVIDIA SDI products
	and the features and limitations of the spec compliment those of
	NVIDIA's line of SDI video output devices.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/present_video.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.present_video import *
from OpenGL.raw.GL.NV.present_video import _EXTENSION_NAME

def glInitPresentVideoNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetVideoivNV=wrapper.wrapper(glGetVideoivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetVideouivNV=wrapper.wrapper(glGetVideouivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetVideoi64vNV=wrapper.wrapper(glGetVideoi64vNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetVideoui64vNV=wrapper.wrapper(glGetVideoui64vNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension KHR.robustness

This module customises the behaviour of the 
OpenGL.raw.GLES2.KHR.robustness to provide a more 
Python-friendly API

Overview (from the spec)
	
	Several recent trends in how OpenGL ES integrates into modern computer
	systems have created new requirements for robustness and security for GL
	rendering contexts.
	
	Additionally GPU architectures now support hardware fault detection;
	for example, video memory supporting ECC (error correcting codes)
	and error detection.  GL contexts should be capable of recovering
	from hardware faults such as uncorrectable memory errors.  Along with
	recovery from such hardware faults, the recovery mechanism can
	also allow recovery from video memory access exceptions and system
	software failures.  System software failures can be due to device
	changes or driver failures.
	
	GL queries that return (write) some number of bytes to a
	buffer indicated by a pointer parameter introduce risk of buffer
	overflows that might be exploitable by malware. To address this,
	queries with return value sizes that are not expressed directly by
	the parameters to the query itself are given additional API
	functions with an additional parameter that specifies the number of
	bytes in the buffer and never writing bytes beyond that limit. This
	is particularly useful for multi-threaded usage of GL contexts
	in a "share group" where one context can change objects in ways that
	can cause buffer overflows for another context's GL queries.
	
	The original ARB_vertex_buffer_object extension includes an issue
	that explicitly states program termination is allowed when
	out-of-bounds vertex buffer object fetches occur. Modern graphics
	hardware is capable of well-defined behavior in the case of out-of-
	bounds vertex buffer object fetches. Older hardware may require
	extra checks to enforce well-defined (and termination free)
	behavior, but this expense is warranted when processing potentially
	untrusted content.
	
	The intent of this extension is to address some specific robustness
	goals:
	
	*   For all existing GL queries, provide additional "safe" APIs 
	    that limit data written to user pointers to a buffer size in 
	    bytes that is an explicit additional parameter of the query.
	
	*   Provide a mechanism for a GL application to learn about
	    graphics resets that affect the context.  When a graphics reset
	    occurs, the GL context becomes unusable and the application
	    must create a new context to continue operation. Detecting a
	    graphics reset happens through an inexpensive query.
	
	*   Define behavior of OpenGL calls made after a graphics reset.
	
	*   Provide an enable to guarantee that out-of-bounds buffer object
	    accesses by the GPU will have deterministic behavior and preclude
	    application instability or termination due to an incorrect buffer
	    access.  Such accesses include vertex buffer fetches of
	    attributes and indices, and indexed reads of uniforms or
	    parameters from buffers.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/KHR/robustness.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.KHR.robustness import *
from OpenGL.raw.GLES2.KHR.robustness import _EXTENSION_NAME

def glInitRobustnessKHR():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glReadnPixelsKHR.data size not checked against bufSize
glReadnPixelsKHR=wrapper.wrapper(glReadnPixelsKHR).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_VERSION_GLX_1_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_VERSION_GLX_1_0',error_checker=_errors._error_checker)
GLX_ACCUM_ALPHA_SIZE=_C('GLX_ACCUM_ALPHA_SIZE',17)
GLX_ACCUM_BLUE_SIZE=_C('GLX_ACCUM_BLUE_SIZE',16)
GLX_ACCUM_GREEN_SIZE=_C('GLX_ACCUM_GREEN_SIZE',15)
GLX_ACCUM_RED_SIZE=_C('GLX_ACCUM_RED_SIZE',14)
GLX_ALPHA_SIZE=_C('GLX_ALPHA_SIZE',11)
GLX_AUX_BUFFERS=_C('GLX_AUX_BUFFERS',7)
GLX_BAD_ATTRIBUTE=_C('GLX_BAD_ATTRIBUTE',2)
GLX_BAD_CONTEXT=_C('GLX_BAD_CONTEXT',5)
GLX_BAD_ENUM=_C('GLX_BAD_ENUM',7)
GLX_BAD_SCREEN=_C('GLX_BAD_SCREEN',1)
GLX_BAD_VALUE=_C('GLX_BAD_VALUE',6)
GLX_BAD_VISUAL=_C('GLX_BAD_VISUAL',4)
GLX_BLUE_SIZE=_C('GLX_BLUE_SIZE',10)
GLX_BUFFER_SIZE=_C('GLX_BUFFER_SIZE',2)
GLX_BufferSwapComplete=_C('GLX_BufferSwapComplete',1)
GLX_DEPTH_SIZE=_C('GLX_DEPTH_SIZE',12)
GLX_DOUBLEBUFFER=_C('GLX_DOUBLEBUFFER',5)
# GLX_EXTENSION_NAME=_C('GLX_EXTENSION_NAME',"GLX")
GLX_GREEN_SIZE=_C('GLX_GREEN_SIZE',9)
GLX_LEVEL=_C('GLX_LEVEL',3)
GLX_NO_EXTENSION=_C('GLX_NO_EXTENSION',3)
GLX_PbufferClobber=_C('GLX_PbufferClobber',0)
GLX_RED_SIZE=_C('GLX_RED_SIZE',8)
GLX_RGBA=_C('GLX_RGBA',4)
GLX_STENCIL_SIZE=_C('GLX_STENCIL_SIZE',13)
GLX_STEREO=_C('GLX_STEREO',6)
GLX_USE_GL=_C('GLX_USE_GL',1)
__GLX_NUMBER_EVENTS=_C('__GLX_NUMBER_EVENTS',17)
@_f
@_p.types(ctypes.POINTER(_cs.XVisualInfo),ctypes.POINTER(_cs.Display),_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXChooseVisual(dpy,screen,attribList):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXContext,_cs.GLXContext,_cs.c_ulong)
def glXCopyContext(dpy,src,dst,mask):pass
@_f
@_p.types(_cs.GLXContext,ctypes.POINTER(_cs.Display),ctypes.POINTER(_cs.XVisualInfo),_cs.GLXContext,_cs.Bool)
def glXCreateContext(dpy,vis,shareList,direct):pass
@_f
@_p.types(_cs.GLXPixmap,ctypes.POINTER(_cs.Display),ctypes.POINTER(_cs.XVisualInfo),_cs.Pixmap)
def glXCreateGLXPixmap(dpy,visual,pixmap):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXContext)
def glXDestroyContext(dpy,ctx):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXPixmap)
def glXDestroyGLXPixmap(dpy,pixmap):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),ctypes.POINTER(_cs.XVisualInfo),_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXGetConfig(dpy,visual,attrib,value):pass
@_f
@_p.types(_cs.GLXContext,)
def glXGetCurrentContext():pass
@_f
@_p.types(_cs.GLXDrawable,)
def glXGetCurrentDrawable():pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXContext)
def glXIsDirect(dpy,ctx):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.GLXContext)
def glXMakeCurrent(dpy,drawable,ctx):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int))
def glXQueryExtension(dpy,errorb,event):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int))
def glXQueryVersion(dpy,maj,min):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXDrawable)
def glXSwapBuffers(dpy,drawable):pass
@_f
@_p.types(None,_cs.Font,_cs.c_int,_cs.c_int,_cs.c_int)
def glXUseXFont(font,first,count,list):pass
@_f
@_p.types(None,)
def glXWaitGL():pass
@_f
@_p.types(None,)
def glXWaitX():pass
